from enum import Enum
import math
import string


class AccelerationUnits(Enum):
        """
            AccelerationUnits enumeration
        """
        
        MeterPerSecondSquared = 'meter_per_second_squared'
        """
            
        """
        
        InchPerSecondSquared = 'inch_per_second_squared'
        """
            
        """
        
        FootPerSecondSquared = 'foot_per_second_squared'
        """
            
        """
        
        KnotPerSecond = 'knot_per_second'
        """
            
        """
        
        KnotPerMinute = 'knot_per_minute'
        """
            
        """
        
        KnotPerHour = 'knot_per_hour'
        """
            
        """
        
        StandardGravity = 'standard_gravity'
        """
            
        """
        
        NanometerPerSecondSquared = 'nanometer_per_second_squared'
        """
            
        """
        
        MicrometerPerSecondSquared = 'micrometer_per_second_squared'
        """
            
        """
        
        MillimeterPerSecondSquared = 'millimeter_per_second_squared'
        """
            
        """
        
        CentimeterPerSecondSquared = 'centimeter_per_second_squared'
        """
            
        """
        
        DecimeterPerSecondSquared = 'decimeter_per_second_squared'
        """
            
        """
        
        KilometerPerSecondSquared = 'kilometer_per_second_squared'
        """
            
        """
        
        MillistandardGravity = 'millistandard_gravity'
        """
            
        """
        

class Acceleration:
    """
    Acceleration, in physics, is the rate at which the velocity of an object changes over time. An object's acceleration is the net result of any and all forces acting on the object, as described by Newton's Second Law. The SI unit for acceleration is the Meter per second squared (m/s²). Accelerations are vector quantities (they have magnitude and direction) and add according to the parallelogram law. As a vector, the calculated net force is equal to the product of the object's mass (a scalar quantity) and the acceleration.

    Args:
        value (float): The value.
        from_unit (AccelerationUnits): The Acceleration unit to create from, The default unit is MeterPerSecondSquared
    """
    def __init__(self, value: float, from_unit: AccelerationUnits = AccelerationUnits.MeterPerSecondSquared):
        if math.isnan(value):
            raise ValueError('Invalid unit: value is NaN')
        self.__value = self.__convert_to_base(value, from_unit)
        
        self.__meters_per_second_squared = None
        
        self.__inches_per_second_squared = None
        
        self.__feet_per_second_squared = None
        
        self.__knots_per_second = None
        
        self.__knots_per_minute = None
        
        self.__knots_per_hour = None
        
        self.__standard_gravity = None
        
        self.__nanometers_per_second_squared = None
        
        self.__micrometers_per_second_squared = None
        
        self.__millimeters_per_second_squared = None
        
        self.__centimeters_per_second_squared = None
        
        self.__decimeters_per_second_squared = None
        
        self.__kilometers_per_second_squared = None
        
        self.__millistandard_gravity = None
        

    def __convert_from_base(self, from_unit: AccelerationUnits) -> float:
        value = self.__value
        
        if from_unit == AccelerationUnits.MeterPerSecondSquared:
            return (value)
        
        if from_unit == AccelerationUnits.InchPerSecondSquared:
            return (value / 0.0254)
        
        if from_unit == AccelerationUnits.FootPerSecondSquared:
            return (value / 0.304800)
        
        if from_unit == AccelerationUnits.KnotPerSecond:
            return (value / 0.5144444444444)
        
        if from_unit == AccelerationUnits.KnotPerMinute:
            return (value / 0.5144444444444 * 60)
        
        if from_unit == AccelerationUnits.KnotPerHour:
            return (value / 0.5144444444444 * 3600)
        
        if from_unit == AccelerationUnits.StandardGravity:
            return (value / 9.80665)
        
        if from_unit == AccelerationUnits.NanometerPerSecondSquared:
            return ((value) / 1e-09)
        
        if from_unit == AccelerationUnits.MicrometerPerSecondSquared:
            return ((value) / 1e-06)
        
        if from_unit == AccelerationUnits.MillimeterPerSecondSquared:
            return ((value) / 0.001)
        
        if from_unit == AccelerationUnits.CentimeterPerSecondSquared:
            return ((value) / 0.01)
        
        if from_unit == AccelerationUnits.DecimeterPerSecondSquared:
            return ((value) / 0.1)
        
        if from_unit == AccelerationUnits.KilometerPerSecondSquared:
            return ((value) / 1000.0)
        
        if from_unit == AccelerationUnits.MillistandardGravity:
            return ((value / 9.80665) / 0.001)
        
        return None


    def __convert_to_base(self, value: float, to_unit: AccelerationUnits) -> float:
        
        if to_unit == AccelerationUnits.MeterPerSecondSquared:
            return (value)
        
        if to_unit == AccelerationUnits.InchPerSecondSquared:
            return (value * 0.0254)
        
        if to_unit == AccelerationUnits.FootPerSecondSquared:
            return (value * 0.304800)
        
        if to_unit == AccelerationUnits.KnotPerSecond:
            return (value * 0.5144444444444)
        
        if to_unit == AccelerationUnits.KnotPerMinute:
            return (value * 0.5144444444444 / 60)
        
        if to_unit == AccelerationUnits.KnotPerHour:
            return (value * 0.5144444444444 / 3600)
        
        if to_unit == AccelerationUnits.StandardGravity:
            return (value * 9.80665)
        
        if to_unit == AccelerationUnits.NanometerPerSecondSquared:
            return ((value) * 1e-09)
        
        if to_unit == AccelerationUnits.MicrometerPerSecondSquared:
            return ((value) * 1e-06)
        
        if to_unit == AccelerationUnits.MillimeterPerSecondSquared:
            return ((value) * 0.001)
        
        if to_unit == AccelerationUnits.CentimeterPerSecondSquared:
            return ((value) * 0.01)
        
        if to_unit == AccelerationUnits.DecimeterPerSecondSquared:
            return ((value) * 0.1)
        
        if to_unit == AccelerationUnits.KilometerPerSecondSquared:
            return ((value) * 1000.0)
        
        if to_unit == AccelerationUnits.MillistandardGravity:
            return ((value * 9.80665) * 0.001)
        
        return None


    @property
    def base_value(self) -> float:
        return self.__value

    
    @staticmethod
    def from_meters_per_second_squared(meters_per_second_squared: float):
        """
        Create a new instance of Acceleration from a value in meters_per_second_squared.

        

        :param meters: The Acceleration value in meters_per_second_squared.
        :type meters_per_second_squared: float
        :return: A new instance of Acceleration.
        :rtype: Acceleration
        """
        return Acceleration(meters_per_second_squared, AccelerationUnits.MeterPerSecondSquared)

    
    @staticmethod
    def from_inches_per_second_squared(inches_per_second_squared: float):
        """
        Create a new instance of Acceleration from a value in inches_per_second_squared.

        

        :param meters: The Acceleration value in inches_per_second_squared.
        :type inches_per_second_squared: float
        :return: A new instance of Acceleration.
        :rtype: Acceleration
        """
        return Acceleration(inches_per_second_squared, AccelerationUnits.InchPerSecondSquared)

    
    @staticmethod
    def from_feet_per_second_squared(feet_per_second_squared: float):
        """
        Create a new instance of Acceleration from a value in feet_per_second_squared.

        

        :param meters: The Acceleration value in feet_per_second_squared.
        :type feet_per_second_squared: float
        :return: A new instance of Acceleration.
        :rtype: Acceleration
        """
        return Acceleration(feet_per_second_squared, AccelerationUnits.FootPerSecondSquared)

    
    @staticmethod
    def from_knots_per_second(knots_per_second: float):
        """
        Create a new instance of Acceleration from a value in knots_per_second.

        

        :param meters: The Acceleration value in knots_per_second.
        :type knots_per_second: float
        :return: A new instance of Acceleration.
        :rtype: Acceleration
        """
        return Acceleration(knots_per_second, AccelerationUnits.KnotPerSecond)

    
    @staticmethod
    def from_knots_per_minute(knots_per_minute: float):
        """
        Create a new instance of Acceleration from a value in knots_per_minute.

        

        :param meters: The Acceleration value in knots_per_minute.
        :type knots_per_minute: float
        :return: A new instance of Acceleration.
        :rtype: Acceleration
        """
        return Acceleration(knots_per_minute, AccelerationUnits.KnotPerMinute)

    
    @staticmethod
    def from_knots_per_hour(knots_per_hour: float):
        """
        Create a new instance of Acceleration from a value in knots_per_hour.

        

        :param meters: The Acceleration value in knots_per_hour.
        :type knots_per_hour: float
        :return: A new instance of Acceleration.
        :rtype: Acceleration
        """
        return Acceleration(knots_per_hour, AccelerationUnits.KnotPerHour)

    
    @staticmethod
    def from_standard_gravity(standard_gravity: float):
        """
        Create a new instance of Acceleration from a value in standard_gravity.

        

        :param meters: The Acceleration value in standard_gravity.
        :type standard_gravity: float
        :return: A new instance of Acceleration.
        :rtype: Acceleration
        """
        return Acceleration(standard_gravity, AccelerationUnits.StandardGravity)

    
    @staticmethod
    def from_nanometers_per_second_squared(nanometers_per_second_squared: float):
        """
        Create a new instance of Acceleration from a value in nanometers_per_second_squared.

        

        :param meters: The Acceleration value in nanometers_per_second_squared.
        :type nanometers_per_second_squared: float
        :return: A new instance of Acceleration.
        :rtype: Acceleration
        """
        return Acceleration(nanometers_per_second_squared, AccelerationUnits.NanometerPerSecondSquared)

    
    @staticmethod
    def from_micrometers_per_second_squared(micrometers_per_second_squared: float):
        """
        Create a new instance of Acceleration from a value in micrometers_per_second_squared.

        

        :param meters: The Acceleration value in micrometers_per_second_squared.
        :type micrometers_per_second_squared: float
        :return: A new instance of Acceleration.
        :rtype: Acceleration
        """
        return Acceleration(micrometers_per_second_squared, AccelerationUnits.MicrometerPerSecondSquared)

    
    @staticmethod
    def from_millimeters_per_second_squared(millimeters_per_second_squared: float):
        """
        Create a new instance of Acceleration from a value in millimeters_per_second_squared.

        

        :param meters: The Acceleration value in millimeters_per_second_squared.
        :type millimeters_per_second_squared: float
        :return: A new instance of Acceleration.
        :rtype: Acceleration
        """
        return Acceleration(millimeters_per_second_squared, AccelerationUnits.MillimeterPerSecondSquared)

    
    @staticmethod
    def from_centimeters_per_second_squared(centimeters_per_second_squared: float):
        """
        Create a new instance of Acceleration from a value in centimeters_per_second_squared.

        

        :param meters: The Acceleration value in centimeters_per_second_squared.
        :type centimeters_per_second_squared: float
        :return: A new instance of Acceleration.
        :rtype: Acceleration
        """
        return Acceleration(centimeters_per_second_squared, AccelerationUnits.CentimeterPerSecondSquared)

    
    @staticmethod
    def from_decimeters_per_second_squared(decimeters_per_second_squared: float):
        """
        Create a new instance of Acceleration from a value in decimeters_per_second_squared.

        

        :param meters: The Acceleration value in decimeters_per_second_squared.
        :type decimeters_per_second_squared: float
        :return: A new instance of Acceleration.
        :rtype: Acceleration
        """
        return Acceleration(decimeters_per_second_squared, AccelerationUnits.DecimeterPerSecondSquared)

    
    @staticmethod
    def from_kilometers_per_second_squared(kilometers_per_second_squared: float):
        """
        Create a new instance of Acceleration from a value in kilometers_per_second_squared.

        

        :param meters: The Acceleration value in kilometers_per_second_squared.
        :type kilometers_per_second_squared: float
        :return: A new instance of Acceleration.
        :rtype: Acceleration
        """
        return Acceleration(kilometers_per_second_squared, AccelerationUnits.KilometerPerSecondSquared)

    
    @staticmethod
    def from_millistandard_gravity(millistandard_gravity: float):
        """
        Create a new instance of Acceleration from a value in millistandard_gravity.

        

        :param meters: The Acceleration value in millistandard_gravity.
        :type millistandard_gravity: float
        :return: A new instance of Acceleration.
        :rtype: Acceleration
        """
        return Acceleration(millistandard_gravity, AccelerationUnits.MillistandardGravity)

    
    @property
    def meters_per_second_squared(self) -> float:
        """
        
        """
        if self.__meters_per_second_squared != None:
            return self.__meters_per_second_squared
        self.__meters_per_second_squared = self.__convert_from_base(AccelerationUnits.MeterPerSecondSquared)
        return self.__meters_per_second_squared

    
    @property
    def inches_per_second_squared(self) -> float:
        """
        
        """
        if self.__inches_per_second_squared != None:
            return self.__inches_per_second_squared
        self.__inches_per_second_squared = self.__convert_from_base(AccelerationUnits.InchPerSecondSquared)
        return self.__inches_per_second_squared

    
    @property
    def feet_per_second_squared(self) -> float:
        """
        
        """
        if self.__feet_per_second_squared != None:
            return self.__feet_per_second_squared
        self.__feet_per_second_squared = self.__convert_from_base(AccelerationUnits.FootPerSecondSquared)
        return self.__feet_per_second_squared

    
    @property
    def knots_per_second(self) -> float:
        """
        
        """
        if self.__knots_per_second != None:
            return self.__knots_per_second
        self.__knots_per_second = self.__convert_from_base(AccelerationUnits.KnotPerSecond)
        return self.__knots_per_second

    
    @property
    def knots_per_minute(self) -> float:
        """
        
        """
        if self.__knots_per_minute != None:
            return self.__knots_per_minute
        self.__knots_per_minute = self.__convert_from_base(AccelerationUnits.KnotPerMinute)
        return self.__knots_per_minute

    
    @property
    def knots_per_hour(self) -> float:
        """
        
        """
        if self.__knots_per_hour != None:
            return self.__knots_per_hour
        self.__knots_per_hour = self.__convert_from_base(AccelerationUnits.KnotPerHour)
        return self.__knots_per_hour

    
    @property
    def standard_gravity(self) -> float:
        """
        
        """
        if self.__standard_gravity != None:
            return self.__standard_gravity
        self.__standard_gravity = self.__convert_from_base(AccelerationUnits.StandardGravity)
        return self.__standard_gravity

    
    @property
    def nanometers_per_second_squared(self) -> float:
        """
        
        """
        if self.__nanometers_per_second_squared != None:
            return self.__nanometers_per_second_squared
        self.__nanometers_per_second_squared = self.__convert_from_base(AccelerationUnits.NanometerPerSecondSquared)
        return self.__nanometers_per_second_squared

    
    @property
    def micrometers_per_second_squared(self) -> float:
        """
        
        """
        if self.__micrometers_per_second_squared != None:
            return self.__micrometers_per_second_squared
        self.__micrometers_per_second_squared = self.__convert_from_base(AccelerationUnits.MicrometerPerSecondSquared)
        return self.__micrometers_per_second_squared

    
    @property
    def millimeters_per_second_squared(self) -> float:
        """
        
        """
        if self.__millimeters_per_second_squared != None:
            return self.__millimeters_per_second_squared
        self.__millimeters_per_second_squared = self.__convert_from_base(AccelerationUnits.MillimeterPerSecondSquared)
        return self.__millimeters_per_second_squared

    
    @property
    def centimeters_per_second_squared(self) -> float:
        """
        
        """
        if self.__centimeters_per_second_squared != None:
            return self.__centimeters_per_second_squared
        self.__centimeters_per_second_squared = self.__convert_from_base(AccelerationUnits.CentimeterPerSecondSquared)
        return self.__centimeters_per_second_squared

    
    @property
    def decimeters_per_second_squared(self) -> float:
        """
        
        """
        if self.__decimeters_per_second_squared != None:
            return self.__decimeters_per_second_squared
        self.__decimeters_per_second_squared = self.__convert_from_base(AccelerationUnits.DecimeterPerSecondSquared)
        return self.__decimeters_per_second_squared

    
    @property
    def kilometers_per_second_squared(self) -> float:
        """
        
        """
        if self.__kilometers_per_second_squared != None:
            return self.__kilometers_per_second_squared
        self.__kilometers_per_second_squared = self.__convert_from_base(AccelerationUnits.KilometerPerSecondSquared)
        return self.__kilometers_per_second_squared

    
    @property
    def millistandard_gravity(self) -> float:
        """
        
        """
        if self.__millistandard_gravity != None:
            return self.__millistandard_gravity
        self.__millistandard_gravity = self.__convert_from_base(AccelerationUnits.MillistandardGravity)
        return self.__millistandard_gravity

    
    def to_string(self, unit: AccelerationUnits = AccelerationUnits.MeterPerSecondSquared) -> string:
        """
        Format the Acceleration to string.
        Note! the default format for Acceleration is MeterPerSecondSquared.
        To specify the unit format set the 'unit' parameter.
        """
        
        if unit == AccelerationUnits.MeterPerSecondSquared:
            return f"""{self.meters_per_second_squared} m/s²"""
        
        if unit == AccelerationUnits.InchPerSecondSquared:
            return f"""{self.inches_per_second_squared} in/s²"""
        
        if unit == AccelerationUnits.FootPerSecondSquared:
            return f"""{self.feet_per_second_squared} ft/s²"""
        
        if unit == AccelerationUnits.KnotPerSecond:
            return f"""{self.knots_per_second} kn/s"""
        
        if unit == AccelerationUnits.KnotPerMinute:
            return f"""{self.knots_per_minute} kn/min"""
        
        if unit == AccelerationUnits.KnotPerHour:
            return f"""{self.knots_per_hour} kn/h"""
        
        if unit == AccelerationUnits.StandardGravity:
            return f"""{self.standard_gravity} g"""
        
        if unit == AccelerationUnits.NanometerPerSecondSquared:
            return f"""{self.nanometers_per_second_squared} """
        
        if unit == AccelerationUnits.MicrometerPerSecondSquared:
            return f"""{self.micrometers_per_second_squared} """
        
        if unit == AccelerationUnits.MillimeterPerSecondSquared:
            return f"""{self.millimeters_per_second_squared} """
        
        if unit == AccelerationUnits.CentimeterPerSecondSquared:
            return f"""{self.centimeters_per_second_squared} """
        
        if unit == AccelerationUnits.DecimeterPerSecondSquared:
            return f"""{self.decimeters_per_second_squared} """
        
        if unit == AccelerationUnits.KilometerPerSecondSquared:
            return f"""{self.kilometers_per_second_squared} """
        
        if unit == AccelerationUnits.MillistandardGravity:
            return f"""{self.millistandard_gravity} """
        
        return f'{self.__value}'


    def get_unit_abbreviation(self, unit_abbreviation: AccelerationUnits = AccelerationUnits.MeterPerSecondSquared) -> string:
        """
        Get Acceleration unit abbreviation.
        Note! the default abbreviation for Acceleration is MeterPerSecondSquared.
        To specify the unit abbreviation set the 'unit_abbreviation' parameter.
        """
        
        if unit_abbreviation == AccelerationUnits.MeterPerSecondSquared:
            return """m/s²"""
        
        if unit_abbreviation == AccelerationUnits.InchPerSecondSquared:
            return """in/s²"""
        
        if unit_abbreviation == AccelerationUnits.FootPerSecondSquared:
            return """ft/s²"""
        
        if unit_abbreviation == AccelerationUnits.KnotPerSecond:
            return """kn/s"""
        
        if unit_abbreviation == AccelerationUnits.KnotPerMinute:
            return """kn/min"""
        
        if unit_abbreviation == AccelerationUnits.KnotPerHour:
            return """kn/h"""
        
        if unit_abbreviation == AccelerationUnits.StandardGravity:
            return """g"""
        
        if unit_abbreviation == AccelerationUnits.NanometerPerSecondSquared:
            return """"""
        
        if unit_abbreviation == AccelerationUnits.MicrometerPerSecondSquared:
            return """"""
        
        if unit_abbreviation == AccelerationUnits.MillimeterPerSecondSquared:
            return """"""
        
        if unit_abbreviation == AccelerationUnits.CentimeterPerSecondSquared:
            return """"""
        
        if unit_abbreviation == AccelerationUnits.DecimeterPerSecondSquared:
            return """"""
        
        if unit_abbreviation == AccelerationUnits.KilometerPerSecondSquared:
            return """"""
        
        if unit_abbreviation == AccelerationUnits.MillistandardGravity:
            return """"""
        

    def __str__(self):
        return self.to_string()


    def __add__(self, other):
        if not isinstance(other, Acceleration):
            raise TypeError("unsupported operand type(s) for +: 'Acceleration' and '{}'".format(type(other).__name__))
        return Acceleration(self.__value + other.__value)


    def __mul__(self, other):
        if not isinstance(other, Acceleration):
            raise TypeError("unsupported operand type(s) for *: 'Acceleration' and '{}'".format(type(other).__name__))
        return Acceleration(self.__value * other.__value)


    def __sub__(self, other):
        if not isinstance(other, Acceleration):
            raise TypeError("unsupported operand type(s) for -: 'Acceleration' and '{}'".format(type(other).__name__))
        return Acceleration(self.__value - other.__value)


    def __truediv__(self, other):
        if not isinstance(other, Acceleration):
            raise TypeError("unsupported operand type(s) for /: 'Acceleration' and '{}'".format(type(other).__name__))
        return Acceleration(self.__value / other.__value)


    def __mod__(self, other):
        if not isinstance(other, Acceleration):
            raise TypeError("unsupported operand type(s) for %: 'Acceleration' and '{}'".format(type(other).__name__))
        return Acceleration(self.__value % other.__value)


    def __pow__(self, other):
        if not isinstance(other, Acceleration):
            raise TypeError("unsupported operand type(s) for **: 'Acceleration' and '{}'".format(type(other).__name__))
        return Acceleration(self.__value ** other.__value)


    def __eq__(self, other):
        if not isinstance(other, Acceleration):
            raise TypeError("unsupported operand type(s) for ==: 'Acceleration' and '{}'".format(type(other).__name__))
        return self.__value == other.__value


    def __lt__(self, other):
        if not isinstance(other, Acceleration):
            raise TypeError("unsupported operand type(s) for <: 'Acceleration' and '{}'".format(type(other).__name__))
        return self.__value < other.__value


    def __gt__(self, other):
        if not isinstance(other, Acceleration):
            raise TypeError("unsupported operand type(s) for >: 'Acceleration' and '{}'".format(type(other).__name__))
        return self.__value > other.__value


    def __le__(self, other):
        if not isinstance(other, Acceleration):
            raise TypeError("unsupported operand type(s) for <=: 'Acceleration' and '{}'".format(type(other).__name__))
        return self.__value <= other.__value


    def __ge__(self, other):
        if not isinstance(other, Acceleration):
            raise TypeError("unsupported operand type(s) for >=: 'Acceleration' and '{}'".format(type(other).__name__))
        return self.__value >= other.__value


from enum import Enum
import math
import string


class SpecificFuelConsumptionUnits(Enum):
        """
            SpecificFuelConsumptionUnits enumeration
        """
        
        PoundMassPerPoundForceHour = 'pound_mass_per_pound_force_hour'
        """
            
        """
        
        KilogramPerKilogramForceHour = 'kilogram_per_kilogram_force_hour'
        """
            
        """
        
        GramPerKiloNewtonSecond = 'gram_per_kilo_newton_second'
        """
            
        """
        
        KilogramPerKiloNewtonSecond = 'kilogram_per_kilo_newton_second'
        """
            
        """
        

class SpecificFuelConsumption:
    """
    SFC is the fuel efficiency of an engine design with respect to thrust output

    Args:
        value (float): The value.
        from_unit (SpecificFuelConsumptionUnits): The SpecificFuelConsumption unit to create from, The default unit is GramPerKiloNewtonSecond
    """
    def __init__(self, value: float, from_unit: SpecificFuelConsumptionUnits = SpecificFuelConsumptionUnits.GramPerKiloNewtonSecond):
        if math.isnan(value):
            raise ValueError('Invalid unit: value is NaN')
        self.__value = self.__convert_to_base(value, from_unit)
        
        self.__pounds_mass_per_pound_force_hour = None
        
        self.__kilograms_per_kilogram_force_hour = None
        
        self.__grams_per_kilo_newton_second = None
        
        self.__kilograms_per_kilo_newton_second = None
        

    def __convert_from_base(self, from_unit: SpecificFuelConsumptionUnits) -> float:
        value = self.__value
        
        if from_unit == SpecificFuelConsumptionUnits.PoundMassPerPoundForceHour:
            return (value / 28.33)
        
        if from_unit == SpecificFuelConsumptionUnits.KilogramPerKilogramForceHour:
            return (value / 28.33)
        
        if from_unit == SpecificFuelConsumptionUnits.GramPerKiloNewtonSecond:
            return (value)
        
        if from_unit == SpecificFuelConsumptionUnits.KilogramPerKiloNewtonSecond:
            return ((value) / 1000.0)
        
        return None


    def __convert_to_base(self, value: float, to_unit: SpecificFuelConsumptionUnits) -> float:
        
        if to_unit == SpecificFuelConsumptionUnits.PoundMassPerPoundForceHour:
            return (value * 28.33)
        
        if to_unit == SpecificFuelConsumptionUnits.KilogramPerKilogramForceHour:
            return (value * 28.33)
        
        if to_unit == SpecificFuelConsumptionUnits.GramPerKiloNewtonSecond:
            return (value)
        
        if to_unit == SpecificFuelConsumptionUnits.KilogramPerKiloNewtonSecond:
            return ((value) * 1000.0)
        
        return None


    @property
    def base_value(self) -> float:
        return self.__value

    
    @staticmethod
    def from_pounds_mass_per_pound_force_hour(pounds_mass_per_pound_force_hour: float):
        """
        Create a new instance of SpecificFuelConsumption from a value in pounds_mass_per_pound_force_hour.

        

        :param meters: The SpecificFuelConsumption value in pounds_mass_per_pound_force_hour.
        :type pounds_mass_per_pound_force_hour: float
        :return: A new instance of SpecificFuelConsumption.
        :rtype: SpecificFuelConsumption
        """
        return SpecificFuelConsumption(pounds_mass_per_pound_force_hour, SpecificFuelConsumptionUnits.PoundMassPerPoundForceHour)

    
    @staticmethod
    def from_kilograms_per_kilogram_force_hour(kilograms_per_kilogram_force_hour: float):
        """
        Create a new instance of SpecificFuelConsumption from a value in kilograms_per_kilogram_force_hour.

        

        :param meters: The SpecificFuelConsumption value in kilograms_per_kilogram_force_hour.
        :type kilograms_per_kilogram_force_hour: float
        :return: A new instance of SpecificFuelConsumption.
        :rtype: SpecificFuelConsumption
        """
        return SpecificFuelConsumption(kilograms_per_kilogram_force_hour, SpecificFuelConsumptionUnits.KilogramPerKilogramForceHour)

    
    @staticmethod
    def from_grams_per_kilo_newton_second(grams_per_kilo_newton_second: float):
        """
        Create a new instance of SpecificFuelConsumption from a value in grams_per_kilo_newton_second.

        

        :param meters: The SpecificFuelConsumption value in grams_per_kilo_newton_second.
        :type grams_per_kilo_newton_second: float
        :return: A new instance of SpecificFuelConsumption.
        :rtype: SpecificFuelConsumption
        """
        return SpecificFuelConsumption(grams_per_kilo_newton_second, SpecificFuelConsumptionUnits.GramPerKiloNewtonSecond)

    
    @staticmethod
    def from_kilograms_per_kilo_newton_second(kilograms_per_kilo_newton_second: float):
        """
        Create a new instance of SpecificFuelConsumption from a value in kilograms_per_kilo_newton_second.

        

        :param meters: The SpecificFuelConsumption value in kilograms_per_kilo_newton_second.
        :type kilograms_per_kilo_newton_second: float
        :return: A new instance of SpecificFuelConsumption.
        :rtype: SpecificFuelConsumption
        """
        return SpecificFuelConsumption(kilograms_per_kilo_newton_second, SpecificFuelConsumptionUnits.KilogramPerKiloNewtonSecond)

    
    @property
    def pounds_mass_per_pound_force_hour(self) -> float:
        """
        
        """
        if self.__pounds_mass_per_pound_force_hour != None:
            return self.__pounds_mass_per_pound_force_hour
        self.__pounds_mass_per_pound_force_hour = self.__convert_from_base(SpecificFuelConsumptionUnits.PoundMassPerPoundForceHour)
        return self.__pounds_mass_per_pound_force_hour

    
    @property
    def kilograms_per_kilogram_force_hour(self) -> float:
        """
        
        """
        if self.__kilograms_per_kilogram_force_hour != None:
            return self.__kilograms_per_kilogram_force_hour
        self.__kilograms_per_kilogram_force_hour = self.__convert_from_base(SpecificFuelConsumptionUnits.KilogramPerKilogramForceHour)
        return self.__kilograms_per_kilogram_force_hour

    
    @property
    def grams_per_kilo_newton_second(self) -> float:
        """
        
        """
        if self.__grams_per_kilo_newton_second != None:
            return self.__grams_per_kilo_newton_second
        self.__grams_per_kilo_newton_second = self.__convert_from_base(SpecificFuelConsumptionUnits.GramPerKiloNewtonSecond)
        return self.__grams_per_kilo_newton_second

    
    @property
    def kilograms_per_kilo_newton_second(self) -> float:
        """
        
        """
        if self.__kilograms_per_kilo_newton_second != None:
            return self.__kilograms_per_kilo_newton_second
        self.__kilograms_per_kilo_newton_second = self.__convert_from_base(SpecificFuelConsumptionUnits.KilogramPerKiloNewtonSecond)
        return self.__kilograms_per_kilo_newton_second

    
    def to_string(self, unit: SpecificFuelConsumptionUnits = SpecificFuelConsumptionUnits.GramPerKiloNewtonSecond) -> string:
        """
        Format the SpecificFuelConsumption to string.
        Note! the default format for SpecificFuelConsumption is GramPerKiloNewtonSecond.
        To specify the unit format set the 'unit' parameter.
        """
        
        if unit == SpecificFuelConsumptionUnits.PoundMassPerPoundForceHour:
            return f"""{self.pounds_mass_per_pound_force_hour} lb/(lbf·h)"""
        
        if unit == SpecificFuelConsumptionUnits.KilogramPerKilogramForceHour:
            return f"""{self.kilograms_per_kilogram_force_hour} kg/(kgf�h)"""
        
        if unit == SpecificFuelConsumptionUnits.GramPerKiloNewtonSecond:
            return f"""{self.grams_per_kilo_newton_second} g/(kN�s)"""
        
        if unit == SpecificFuelConsumptionUnits.KilogramPerKiloNewtonSecond:
            return f"""{self.kilograms_per_kilo_newton_second} """
        
        return f'{self.__value}'


    def get_unit_abbreviation(self, unit_abbreviation: SpecificFuelConsumptionUnits = SpecificFuelConsumptionUnits.GramPerKiloNewtonSecond) -> string:
        """
        Get SpecificFuelConsumption unit abbreviation.
        Note! the default abbreviation for SpecificFuelConsumption is GramPerKiloNewtonSecond.
        To specify the unit abbreviation set the 'unit_abbreviation' parameter.
        """
        
        if unit_abbreviation == SpecificFuelConsumptionUnits.PoundMassPerPoundForceHour:
            return """lb/(lbf·h)"""
        
        if unit_abbreviation == SpecificFuelConsumptionUnits.KilogramPerKilogramForceHour:
            return """kg/(kgf�h)"""
        
        if unit_abbreviation == SpecificFuelConsumptionUnits.GramPerKiloNewtonSecond:
            return """g/(kN�s)"""
        
        if unit_abbreviation == SpecificFuelConsumptionUnits.KilogramPerKiloNewtonSecond:
            return """"""
        

    def __str__(self):
        return self.to_string()


    def __add__(self, other):
        if not isinstance(other, SpecificFuelConsumption):
            raise TypeError("unsupported operand type(s) for +: 'SpecificFuelConsumption' and '{}'".format(type(other).__name__))
        return SpecificFuelConsumption(self.__value + other.__value)


    def __mul__(self, other):
        if not isinstance(other, SpecificFuelConsumption):
            raise TypeError("unsupported operand type(s) for *: 'SpecificFuelConsumption' and '{}'".format(type(other).__name__))
        return SpecificFuelConsumption(self.__value * other.__value)


    def __sub__(self, other):
        if not isinstance(other, SpecificFuelConsumption):
            raise TypeError("unsupported operand type(s) for -: 'SpecificFuelConsumption' and '{}'".format(type(other).__name__))
        return SpecificFuelConsumption(self.__value - other.__value)


    def __truediv__(self, other):
        if not isinstance(other, SpecificFuelConsumption):
            raise TypeError("unsupported operand type(s) for /: 'SpecificFuelConsumption' and '{}'".format(type(other).__name__))
        return SpecificFuelConsumption(self.__value / other.__value)


    def __mod__(self, other):
        if not isinstance(other, SpecificFuelConsumption):
            raise TypeError("unsupported operand type(s) for %: 'SpecificFuelConsumption' and '{}'".format(type(other).__name__))
        return SpecificFuelConsumption(self.__value % other.__value)


    def __pow__(self, other):
        if not isinstance(other, SpecificFuelConsumption):
            raise TypeError("unsupported operand type(s) for **: 'SpecificFuelConsumption' and '{}'".format(type(other).__name__))
        return SpecificFuelConsumption(self.__value ** other.__value)


    def __eq__(self, other):
        if not isinstance(other, SpecificFuelConsumption):
            raise TypeError("unsupported operand type(s) for ==: 'SpecificFuelConsumption' and '{}'".format(type(other).__name__))
        return self.__value == other.__value


    def __lt__(self, other):
        if not isinstance(other, SpecificFuelConsumption):
            raise TypeError("unsupported operand type(s) for <: 'SpecificFuelConsumption' and '{}'".format(type(other).__name__))
        return self.__value < other.__value


    def __gt__(self, other):
        if not isinstance(other, SpecificFuelConsumption):
            raise TypeError("unsupported operand type(s) for >: 'SpecificFuelConsumption' and '{}'".format(type(other).__name__))
        return self.__value > other.__value


    def __le__(self, other):
        if not isinstance(other, SpecificFuelConsumption):
            raise TypeError("unsupported operand type(s) for <=: 'SpecificFuelConsumption' and '{}'".format(type(other).__name__))
        return self.__value <= other.__value


    def __ge__(self, other):
        if not isinstance(other, SpecificFuelConsumption):
            raise TypeError("unsupported operand type(s) for >=: 'SpecificFuelConsumption' and '{}'".format(type(other).__name__))
        return self.__value >= other.__value


from enum import Enum
import math
import string


class TemperatureChangeRateUnits(Enum):
        """
            TemperatureChangeRateUnits enumeration
        """
        
        DegreeCelsiusPerSecond = 'degree_celsius_per_second'
        """
            
        """
        
        DegreeCelsiusPerMinute = 'degree_celsius_per_minute'
        """
            
        """
        
        NanodegreeCelsiusPerSecond = 'nanodegree_celsius_per_second'
        """
            
        """
        
        MicrodegreeCelsiusPerSecond = 'microdegree_celsius_per_second'
        """
            
        """
        
        MillidegreeCelsiusPerSecond = 'millidegree_celsius_per_second'
        """
            
        """
        
        CentidegreeCelsiusPerSecond = 'centidegree_celsius_per_second'
        """
            
        """
        
        DecidegreeCelsiusPerSecond = 'decidegree_celsius_per_second'
        """
            
        """
        
        DecadegreeCelsiusPerSecond = 'decadegree_celsius_per_second'
        """
            
        """
        
        HectodegreeCelsiusPerSecond = 'hectodegree_celsius_per_second'
        """
            
        """
        
        KilodegreeCelsiusPerSecond = 'kilodegree_celsius_per_second'
        """
            
        """
        

class TemperatureChangeRate:
    """
    Temperature change rate is the ratio of the temperature change to the time during which the change occurred (value of temperature changes per unit time).

    Args:
        value (float): The value.
        from_unit (TemperatureChangeRateUnits): The TemperatureChangeRate unit to create from, The default unit is DegreeCelsiusPerSecond
    """
    def __init__(self, value: float, from_unit: TemperatureChangeRateUnits = TemperatureChangeRateUnits.DegreeCelsiusPerSecond):
        if math.isnan(value):
            raise ValueError('Invalid unit: value is NaN')
        self.__value = self.__convert_to_base(value, from_unit)
        
        self.__degrees_celsius_per_second = None
        
        self.__degrees_celsius_per_minute = None
        
        self.__nanodegrees_celsius_per_second = None
        
        self.__microdegrees_celsius_per_second = None
        
        self.__millidegrees_celsius_per_second = None
        
        self.__centidegrees_celsius_per_second = None
        
        self.__decidegrees_celsius_per_second = None
        
        self.__decadegrees_celsius_per_second = None
        
        self.__hectodegrees_celsius_per_second = None
        
        self.__kilodegrees_celsius_per_second = None
        

    def __convert_from_base(self, from_unit: TemperatureChangeRateUnits) -> float:
        value = self.__value
        
        if from_unit == TemperatureChangeRateUnits.DegreeCelsiusPerSecond:
            return (value)
        
        if from_unit == TemperatureChangeRateUnits.DegreeCelsiusPerMinute:
            return (value * 60)
        
        if from_unit == TemperatureChangeRateUnits.NanodegreeCelsiusPerSecond:
            return ((value) / 1e-09)
        
        if from_unit == TemperatureChangeRateUnits.MicrodegreeCelsiusPerSecond:
            return ((value) / 1e-06)
        
        if from_unit == TemperatureChangeRateUnits.MillidegreeCelsiusPerSecond:
            return ((value) / 0.001)
        
        if from_unit == TemperatureChangeRateUnits.CentidegreeCelsiusPerSecond:
            return ((value) / 0.01)
        
        if from_unit == TemperatureChangeRateUnits.DecidegreeCelsiusPerSecond:
            return ((value) / 0.1)
        
        if from_unit == TemperatureChangeRateUnits.DecadegreeCelsiusPerSecond:
            return ((value) / 10.0)
        
        if from_unit == TemperatureChangeRateUnits.HectodegreeCelsiusPerSecond:
            return ((value) / 100.0)
        
        if from_unit == TemperatureChangeRateUnits.KilodegreeCelsiusPerSecond:
            return ((value) / 1000.0)
        
        return None


    def __convert_to_base(self, value: float, to_unit: TemperatureChangeRateUnits) -> float:
        
        if to_unit == TemperatureChangeRateUnits.DegreeCelsiusPerSecond:
            return (value)
        
        if to_unit == TemperatureChangeRateUnits.DegreeCelsiusPerMinute:
            return (value / 60)
        
        if to_unit == TemperatureChangeRateUnits.NanodegreeCelsiusPerSecond:
            return ((value) * 1e-09)
        
        if to_unit == TemperatureChangeRateUnits.MicrodegreeCelsiusPerSecond:
            return ((value) * 1e-06)
        
        if to_unit == TemperatureChangeRateUnits.MillidegreeCelsiusPerSecond:
            return ((value) * 0.001)
        
        if to_unit == TemperatureChangeRateUnits.CentidegreeCelsiusPerSecond:
            return ((value) * 0.01)
        
        if to_unit == TemperatureChangeRateUnits.DecidegreeCelsiusPerSecond:
            return ((value) * 0.1)
        
        if to_unit == TemperatureChangeRateUnits.DecadegreeCelsiusPerSecond:
            return ((value) * 10.0)
        
        if to_unit == TemperatureChangeRateUnits.HectodegreeCelsiusPerSecond:
            return ((value) * 100.0)
        
        if to_unit == TemperatureChangeRateUnits.KilodegreeCelsiusPerSecond:
            return ((value) * 1000.0)
        
        return None


    @property
    def base_value(self) -> float:
        return self.__value

    
    @staticmethod
    def from_degrees_celsius_per_second(degrees_celsius_per_second: float):
        """
        Create a new instance of TemperatureChangeRate from a value in degrees_celsius_per_second.

        

        :param meters: The TemperatureChangeRate value in degrees_celsius_per_second.
        :type degrees_celsius_per_second: float
        :return: A new instance of TemperatureChangeRate.
        :rtype: TemperatureChangeRate
        """
        return TemperatureChangeRate(degrees_celsius_per_second, TemperatureChangeRateUnits.DegreeCelsiusPerSecond)

    
    @staticmethod
    def from_degrees_celsius_per_minute(degrees_celsius_per_minute: float):
        """
        Create a new instance of TemperatureChangeRate from a value in degrees_celsius_per_minute.

        

        :param meters: The TemperatureChangeRate value in degrees_celsius_per_minute.
        :type degrees_celsius_per_minute: float
        :return: A new instance of TemperatureChangeRate.
        :rtype: TemperatureChangeRate
        """
        return TemperatureChangeRate(degrees_celsius_per_minute, TemperatureChangeRateUnits.DegreeCelsiusPerMinute)

    
    @staticmethod
    def from_nanodegrees_celsius_per_second(nanodegrees_celsius_per_second: float):
        """
        Create a new instance of TemperatureChangeRate from a value in nanodegrees_celsius_per_second.

        

        :param meters: The TemperatureChangeRate value in nanodegrees_celsius_per_second.
        :type nanodegrees_celsius_per_second: float
        :return: A new instance of TemperatureChangeRate.
        :rtype: TemperatureChangeRate
        """
        return TemperatureChangeRate(nanodegrees_celsius_per_second, TemperatureChangeRateUnits.NanodegreeCelsiusPerSecond)

    
    @staticmethod
    def from_microdegrees_celsius_per_second(microdegrees_celsius_per_second: float):
        """
        Create a new instance of TemperatureChangeRate from a value in microdegrees_celsius_per_second.

        

        :param meters: The TemperatureChangeRate value in microdegrees_celsius_per_second.
        :type microdegrees_celsius_per_second: float
        :return: A new instance of TemperatureChangeRate.
        :rtype: TemperatureChangeRate
        """
        return TemperatureChangeRate(microdegrees_celsius_per_second, TemperatureChangeRateUnits.MicrodegreeCelsiusPerSecond)

    
    @staticmethod
    def from_millidegrees_celsius_per_second(millidegrees_celsius_per_second: float):
        """
        Create a new instance of TemperatureChangeRate from a value in millidegrees_celsius_per_second.

        

        :param meters: The TemperatureChangeRate value in millidegrees_celsius_per_second.
        :type millidegrees_celsius_per_second: float
        :return: A new instance of TemperatureChangeRate.
        :rtype: TemperatureChangeRate
        """
        return TemperatureChangeRate(millidegrees_celsius_per_second, TemperatureChangeRateUnits.MillidegreeCelsiusPerSecond)

    
    @staticmethod
    def from_centidegrees_celsius_per_second(centidegrees_celsius_per_second: float):
        """
        Create a new instance of TemperatureChangeRate from a value in centidegrees_celsius_per_second.

        

        :param meters: The TemperatureChangeRate value in centidegrees_celsius_per_second.
        :type centidegrees_celsius_per_second: float
        :return: A new instance of TemperatureChangeRate.
        :rtype: TemperatureChangeRate
        """
        return TemperatureChangeRate(centidegrees_celsius_per_second, TemperatureChangeRateUnits.CentidegreeCelsiusPerSecond)

    
    @staticmethod
    def from_decidegrees_celsius_per_second(decidegrees_celsius_per_second: float):
        """
        Create a new instance of TemperatureChangeRate from a value in decidegrees_celsius_per_second.

        

        :param meters: The TemperatureChangeRate value in decidegrees_celsius_per_second.
        :type decidegrees_celsius_per_second: float
        :return: A new instance of TemperatureChangeRate.
        :rtype: TemperatureChangeRate
        """
        return TemperatureChangeRate(decidegrees_celsius_per_second, TemperatureChangeRateUnits.DecidegreeCelsiusPerSecond)

    
    @staticmethod
    def from_decadegrees_celsius_per_second(decadegrees_celsius_per_second: float):
        """
        Create a new instance of TemperatureChangeRate from a value in decadegrees_celsius_per_second.

        

        :param meters: The TemperatureChangeRate value in decadegrees_celsius_per_second.
        :type decadegrees_celsius_per_second: float
        :return: A new instance of TemperatureChangeRate.
        :rtype: TemperatureChangeRate
        """
        return TemperatureChangeRate(decadegrees_celsius_per_second, TemperatureChangeRateUnits.DecadegreeCelsiusPerSecond)

    
    @staticmethod
    def from_hectodegrees_celsius_per_second(hectodegrees_celsius_per_second: float):
        """
        Create a new instance of TemperatureChangeRate from a value in hectodegrees_celsius_per_second.

        

        :param meters: The TemperatureChangeRate value in hectodegrees_celsius_per_second.
        :type hectodegrees_celsius_per_second: float
        :return: A new instance of TemperatureChangeRate.
        :rtype: TemperatureChangeRate
        """
        return TemperatureChangeRate(hectodegrees_celsius_per_second, TemperatureChangeRateUnits.HectodegreeCelsiusPerSecond)

    
    @staticmethod
    def from_kilodegrees_celsius_per_second(kilodegrees_celsius_per_second: float):
        """
        Create a new instance of TemperatureChangeRate from a value in kilodegrees_celsius_per_second.

        

        :param meters: The TemperatureChangeRate value in kilodegrees_celsius_per_second.
        :type kilodegrees_celsius_per_second: float
        :return: A new instance of TemperatureChangeRate.
        :rtype: TemperatureChangeRate
        """
        return TemperatureChangeRate(kilodegrees_celsius_per_second, TemperatureChangeRateUnits.KilodegreeCelsiusPerSecond)

    
    @property
    def degrees_celsius_per_second(self) -> float:
        """
        
        """
        if self.__degrees_celsius_per_second != None:
            return self.__degrees_celsius_per_second
        self.__degrees_celsius_per_second = self.__convert_from_base(TemperatureChangeRateUnits.DegreeCelsiusPerSecond)
        return self.__degrees_celsius_per_second

    
    @property
    def degrees_celsius_per_minute(self) -> float:
        """
        
        """
        if self.__degrees_celsius_per_minute != None:
            return self.__degrees_celsius_per_minute
        self.__degrees_celsius_per_minute = self.__convert_from_base(TemperatureChangeRateUnits.DegreeCelsiusPerMinute)
        return self.__degrees_celsius_per_minute

    
    @property
    def nanodegrees_celsius_per_second(self) -> float:
        """
        
        """
        if self.__nanodegrees_celsius_per_second != None:
            return self.__nanodegrees_celsius_per_second
        self.__nanodegrees_celsius_per_second = self.__convert_from_base(TemperatureChangeRateUnits.NanodegreeCelsiusPerSecond)
        return self.__nanodegrees_celsius_per_second

    
    @property
    def microdegrees_celsius_per_second(self) -> float:
        """
        
        """
        if self.__microdegrees_celsius_per_second != None:
            return self.__microdegrees_celsius_per_second
        self.__microdegrees_celsius_per_second = self.__convert_from_base(TemperatureChangeRateUnits.MicrodegreeCelsiusPerSecond)
        return self.__microdegrees_celsius_per_second

    
    @property
    def millidegrees_celsius_per_second(self) -> float:
        """
        
        """
        if self.__millidegrees_celsius_per_second != None:
            return self.__millidegrees_celsius_per_second
        self.__millidegrees_celsius_per_second = self.__convert_from_base(TemperatureChangeRateUnits.MillidegreeCelsiusPerSecond)
        return self.__millidegrees_celsius_per_second

    
    @property
    def centidegrees_celsius_per_second(self) -> float:
        """
        
        """
        if self.__centidegrees_celsius_per_second != None:
            return self.__centidegrees_celsius_per_second
        self.__centidegrees_celsius_per_second = self.__convert_from_base(TemperatureChangeRateUnits.CentidegreeCelsiusPerSecond)
        return self.__centidegrees_celsius_per_second

    
    @property
    def decidegrees_celsius_per_second(self) -> float:
        """
        
        """
        if self.__decidegrees_celsius_per_second != None:
            return self.__decidegrees_celsius_per_second
        self.__decidegrees_celsius_per_second = self.__convert_from_base(TemperatureChangeRateUnits.DecidegreeCelsiusPerSecond)
        return self.__decidegrees_celsius_per_second

    
    @property
    def decadegrees_celsius_per_second(self) -> float:
        """
        
        """
        if self.__decadegrees_celsius_per_second != None:
            return self.__decadegrees_celsius_per_second
        self.__decadegrees_celsius_per_second = self.__convert_from_base(TemperatureChangeRateUnits.DecadegreeCelsiusPerSecond)
        return self.__decadegrees_celsius_per_second

    
    @property
    def hectodegrees_celsius_per_second(self) -> float:
        """
        
        """
        if self.__hectodegrees_celsius_per_second != None:
            return self.__hectodegrees_celsius_per_second
        self.__hectodegrees_celsius_per_second = self.__convert_from_base(TemperatureChangeRateUnits.HectodegreeCelsiusPerSecond)
        return self.__hectodegrees_celsius_per_second

    
    @property
    def kilodegrees_celsius_per_second(self) -> float:
        """
        
        """
        if self.__kilodegrees_celsius_per_second != None:
            return self.__kilodegrees_celsius_per_second
        self.__kilodegrees_celsius_per_second = self.__convert_from_base(TemperatureChangeRateUnits.KilodegreeCelsiusPerSecond)
        return self.__kilodegrees_celsius_per_second

    
    def to_string(self, unit: TemperatureChangeRateUnits = TemperatureChangeRateUnits.DegreeCelsiusPerSecond) -> string:
        """
        Format the TemperatureChangeRate to string.
        Note! the default format for TemperatureChangeRate is DegreeCelsiusPerSecond.
        To specify the unit format set the 'unit' parameter.
        """
        
        if unit == TemperatureChangeRateUnits.DegreeCelsiusPerSecond:
            return f"""{self.degrees_celsius_per_second} °C/s"""
        
        if unit == TemperatureChangeRateUnits.DegreeCelsiusPerMinute:
            return f"""{self.degrees_celsius_per_minute} °C/min"""
        
        if unit == TemperatureChangeRateUnits.NanodegreeCelsiusPerSecond:
            return f"""{self.nanodegrees_celsius_per_second} """
        
        if unit == TemperatureChangeRateUnits.MicrodegreeCelsiusPerSecond:
            return f"""{self.microdegrees_celsius_per_second} """
        
        if unit == TemperatureChangeRateUnits.MillidegreeCelsiusPerSecond:
            return f"""{self.millidegrees_celsius_per_second} """
        
        if unit == TemperatureChangeRateUnits.CentidegreeCelsiusPerSecond:
            return f"""{self.centidegrees_celsius_per_second} """
        
        if unit == TemperatureChangeRateUnits.DecidegreeCelsiusPerSecond:
            return f"""{self.decidegrees_celsius_per_second} """
        
        if unit == TemperatureChangeRateUnits.DecadegreeCelsiusPerSecond:
            return f"""{self.decadegrees_celsius_per_second} """
        
        if unit == TemperatureChangeRateUnits.HectodegreeCelsiusPerSecond:
            return f"""{self.hectodegrees_celsius_per_second} """
        
        if unit == TemperatureChangeRateUnits.KilodegreeCelsiusPerSecond:
            return f"""{self.kilodegrees_celsius_per_second} """
        
        return f'{self.__value}'


    def get_unit_abbreviation(self, unit_abbreviation: TemperatureChangeRateUnits = TemperatureChangeRateUnits.DegreeCelsiusPerSecond) -> string:
        """
        Get TemperatureChangeRate unit abbreviation.
        Note! the default abbreviation for TemperatureChangeRate is DegreeCelsiusPerSecond.
        To specify the unit abbreviation set the 'unit_abbreviation' parameter.
        """
        
        if unit_abbreviation == TemperatureChangeRateUnits.DegreeCelsiusPerSecond:
            return """°C/s"""
        
        if unit_abbreviation == TemperatureChangeRateUnits.DegreeCelsiusPerMinute:
            return """°C/min"""
        
        if unit_abbreviation == TemperatureChangeRateUnits.NanodegreeCelsiusPerSecond:
            return """"""
        
        if unit_abbreviation == TemperatureChangeRateUnits.MicrodegreeCelsiusPerSecond:
            return """"""
        
        if unit_abbreviation == TemperatureChangeRateUnits.MillidegreeCelsiusPerSecond:
            return """"""
        
        if unit_abbreviation == TemperatureChangeRateUnits.CentidegreeCelsiusPerSecond:
            return """"""
        
        if unit_abbreviation == TemperatureChangeRateUnits.DecidegreeCelsiusPerSecond:
            return """"""
        
        if unit_abbreviation == TemperatureChangeRateUnits.DecadegreeCelsiusPerSecond:
            return """"""
        
        if unit_abbreviation == TemperatureChangeRateUnits.HectodegreeCelsiusPerSecond:
            return """"""
        
        if unit_abbreviation == TemperatureChangeRateUnits.KilodegreeCelsiusPerSecond:
            return """"""
        

    def __str__(self):
        return self.to_string()


    def __add__(self, other):
        if not isinstance(other, TemperatureChangeRate):
            raise TypeError("unsupported operand type(s) for +: 'TemperatureChangeRate' and '{}'".format(type(other).__name__))
        return TemperatureChangeRate(self.__value + other.__value)


    def __mul__(self, other):
        if not isinstance(other, TemperatureChangeRate):
            raise TypeError("unsupported operand type(s) for *: 'TemperatureChangeRate' and '{}'".format(type(other).__name__))
        return TemperatureChangeRate(self.__value * other.__value)


    def __sub__(self, other):
        if not isinstance(other, TemperatureChangeRate):
            raise TypeError("unsupported operand type(s) for -: 'TemperatureChangeRate' and '{}'".format(type(other).__name__))
        return TemperatureChangeRate(self.__value - other.__value)


    def __truediv__(self, other):
        if not isinstance(other, TemperatureChangeRate):
            raise TypeError("unsupported operand type(s) for /: 'TemperatureChangeRate' and '{}'".format(type(other).__name__))
        return TemperatureChangeRate(self.__value / other.__value)


    def __mod__(self, other):
        if not isinstance(other, TemperatureChangeRate):
            raise TypeError("unsupported operand type(s) for %: 'TemperatureChangeRate' and '{}'".format(type(other).__name__))
        return TemperatureChangeRate(self.__value % other.__value)


    def __pow__(self, other):
        if not isinstance(other, TemperatureChangeRate):
            raise TypeError("unsupported operand type(s) for **: 'TemperatureChangeRate' and '{}'".format(type(other).__name__))
        return TemperatureChangeRate(self.__value ** other.__value)


    def __eq__(self, other):
        if not isinstance(other, TemperatureChangeRate):
            raise TypeError("unsupported operand type(s) for ==: 'TemperatureChangeRate' and '{}'".format(type(other).__name__))
        return self.__value == other.__value


    def __lt__(self, other):
        if not isinstance(other, TemperatureChangeRate):
            raise TypeError("unsupported operand type(s) for <: 'TemperatureChangeRate' and '{}'".format(type(other).__name__))
        return self.__value < other.__value


    def __gt__(self, other):
        if not isinstance(other, TemperatureChangeRate):
            raise TypeError("unsupported operand type(s) for >: 'TemperatureChangeRate' and '{}'".format(type(other).__name__))
        return self.__value > other.__value


    def __le__(self, other):
        if not isinstance(other, TemperatureChangeRate):
            raise TypeError("unsupported operand type(s) for <=: 'TemperatureChangeRate' and '{}'".format(type(other).__name__))
        return self.__value <= other.__value


    def __ge__(self, other):
        if not isinstance(other, TemperatureChangeRate):
            raise TypeError("unsupported operand type(s) for >=: 'TemperatureChangeRate' and '{}'".format(type(other).__name__))
        return self.__value >= other.__value


from enum import Enum
import math
import string


class MolarEnergyUnits(Enum):
        """
            MolarEnergyUnits enumeration
        """
        
        JoulePerMole = 'joule_per_mole'
        """
            
        """
        
        KilojoulePerMole = 'kilojoule_per_mole'
        """
            
        """
        
        MegajoulePerMole = 'megajoule_per_mole'
        """
            
        """
        

class MolarEnergy:
    """
    Molar energy is the amount of energy stored in 1 mole of a substance.

    Args:
        value (float): The value.
        from_unit (MolarEnergyUnits): The MolarEnergy unit to create from, The default unit is JoulePerMole
    """
    def __init__(self, value: float, from_unit: MolarEnergyUnits = MolarEnergyUnits.JoulePerMole):
        if math.isnan(value):
            raise ValueError('Invalid unit: value is NaN')
        self.__value = self.__convert_to_base(value, from_unit)
        
        self.__joules_per_mole = None
        
        self.__kilojoules_per_mole = None
        
        self.__megajoules_per_mole = None
        

    def __convert_from_base(self, from_unit: MolarEnergyUnits) -> float:
        value = self.__value
        
        if from_unit == MolarEnergyUnits.JoulePerMole:
            return (value)
        
        if from_unit == MolarEnergyUnits.KilojoulePerMole:
            return ((value) / 1000.0)
        
        if from_unit == MolarEnergyUnits.MegajoulePerMole:
            return ((value) / 1000000.0)
        
        return None


    def __convert_to_base(self, value: float, to_unit: MolarEnergyUnits) -> float:
        
        if to_unit == MolarEnergyUnits.JoulePerMole:
            return (value)
        
        if to_unit == MolarEnergyUnits.KilojoulePerMole:
            return ((value) * 1000.0)
        
        if to_unit == MolarEnergyUnits.MegajoulePerMole:
            return ((value) * 1000000.0)
        
        return None


    @property
    def base_value(self) -> float:
        return self.__value

    
    @staticmethod
    def from_joules_per_mole(joules_per_mole: float):
        """
        Create a new instance of MolarEnergy from a value in joules_per_mole.

        

        :param meters: The MolarEnergy value in joules_per_mole.
        :type joules_per_mole: float
        :return: A new instance of MolarEnergy.
        :rtype: MolarEnergy
        """
        return MolarEnergy(joules_per_mole, MolarEnergyUnits.JoulePerMole)

    
    @staticmethod
    def from_kilojoules_per_mole(kilojoules_per_mole: float):
        """
        Create a new instance of MolarEnergy from a value in kilojoules_per_mole.

        

        :param meters: The MolarEnergy value in kilojoules_per_mole.
        :type kilojoules_per_mole: float
        :return: A new instance of MolarEnergy.
        :rtype: MolarEnergy
        """
        return MolarEnergy(kilojoules_per_mole, MolarEnergyUnits.KilojoulePerMole)

    
    @staticmethod
    def from_megajoules_per_mole(megajoules_per_mole: float):
        """
        Create a new instance of MolarEnergy from a value in megajoules_per_mole.

        

        :param meters: The MolarEnergy value in megajoules_per_mole.
        :type megajoules_per_mole: float
        :return: A new instance of MolarEnergy.
        :rtype: MolarEnergy
        """
        return MolarEnergy(megajoules_per_mole, MolarEnergyUnits.MegajoulePerMole)

    
    @property
    def joules_per_mole(self) -> float:
        """
        
        """
        if self.__joules_per_mole != None:
            return self.__joules_per_mole
        self.__joules_per_mole = self.__convert_from_base(MolarEnergyUnits.JoulePerMole)
        return self.__joules_per_mole

    
    @property
    def kilojoules_per_mole(self) -> float:
        """
        
        """
        if self.__kilojoules_per_mole != None:
            return self.__kilojoules_per_mole
        self.__kilojoules_per_mole = self.__convert_from_base(MolarEnergyUnits.KilojoulePerMole)
        return self.__kilojoules_per_mole

    
    @property
    def megajoules_per_mole(self) -> float:
        """
        
        """
        if self.__megajoules_per_mole != None:
            return self.__megajoules_per_mole
        self.__megajoules_per_mole = self.__convert_from_base(MolarEnergyUnits.MegajoulePerMole)
        return self.__megajoules_per_mole

    
    def to_string(self, unit: MolarEnergyUnits = MolarEnergyUnits.JoulePerMole) -> string:
        """
        Format the MolarEnergy to string.
        Note! the default format for MolarEnergy is JoulePerMole.
        To specify the unit format set the 'unit' parameter.
        """
        
        if unit == MolarEnergyUnits.JoulePerMole:
            return f"""{self.joules_per_mole} J/mol"""
        
        if unit == MolarEnergyUnits.KilojoulePerMole:
            return f"""{self.kilojoules_per_mole} """
        
        if unit == MolarEnergyUnits.MegajoulePerMole:
            return f"""{self.megajoules_per_mole} """
        
        return f'{self.__value}'


    def get_unit_abbreviation(self, unit_abbreviation: MolarEnergyUnits = MolarEnergyUnits.JoulePerMole) -> string:
        """
        Get MolarEnergy unit abbreviation.
        Note! the default abbreviation for MolarEnergy is JoulePerMole.
        To specify the unit abbreviation set the 'unit_abbreviation' parameter.
        """
        
        if unit_abbreviation == MolarEnergyUnits.JoulePerMole:
            return """J/mol"""
        
        if unit_abbreviation == MolarEnergyUnits.KilojoulePerMole:
            return """"""
        
        if unit_abbreviation == MolarEnergyUnits.MegajoulePerMole:
            return """"""
        

    def __str__(self):
        return self.to_string()


    def __add__(self, other):
        if not isinstance(other, MolarEnergy):
            raise TypeError("unsupported operand type(s) for +: 'MolarEnergy' and '{}'".format(type(other).__name__))
        return MolarEnergy(self.__value + other.__value)


    def __mul__(self, other):
        if not isinstance(other, MolarEnergy):
            raise TypeError("unsupported operand type(s) for *: 'MolarEnergy' and '{}'".format(type(other).__name__))
        return MolarEnergy(self.__value * other.__value)


    def __sub__(self, other):
        if not isinstance(other, MolarEnergy):
            raise TypeError("unsupported operand type(s) for -: 'MolarEnergy' and '{}'".format(type(other).__name__))
        return MolarEnergy(self.__value - other.__value)


    def __truediv__(self, other):
        if not isinstance(other, MolarEnergy):
            raise TypeError("unsupported operand type(s) for /: 'MolarEnergy' and '{}'".format(type(other).__name__))
        return MolarEnergy(self.__value / other.__value)


    def __mod__(self, other):
        if not isinstance(other, MolarEnergy):
            raise TypeError("unsupported operand type(s) for %: 'MolarEnergy' and '{}'".format(type(other).__name__))
        return MolarEnergy(self.__value % other.__value)


    def __pow__(self, other):
        if not isinstance(other, MolarEnergy):
            raise TypeError("unsupported operand type(s) for **: 'MolarEnergy' and '{}'".format(type(other).__name__))
        return MolarEnergy(self.__value ** other.__value)


    def __eq__(self, other):
        if not isinstance(other, MolarEnergy):
            raise TypeError("unsupported operand type(s) for ==: 'MolarEnergy' and '{}'".format(type(other).__name__))
        return self.__value == other.__value


    def __lt__(self, other):
        if not isinstance(other, MolarEnergy):
            raise TypeError("unsupported operand type(s) for <: 'MolarEnergy' and '{}'".format(type(other).__name__))
        return self.__value < other.__value


    def __gt__(self, other):
        if not isinstance(other, MolarEnergy):
            raise TypeError("unsupported operand type(s) for >: 'MolarEnergy' and '{}'".format(type(other).__name__))
        return self.__value > other.__value


    def __le__(self, other):
        if not isinstance(other, MolarEnergy):
            raise TypeError("unsupported operand type(s) for <=: 'MolarEnergy' and '{}'".format(type(other).__name__))
        return self.__value <= other.__value


    def __ge__(self, other):
        if not isinstance(other, MolarEnergy):
            raise TypeError("unsupported operand type(s) for >=: 'MolarEnergy' and '{}'".format(type(other).__name__))
        return self.__value >= other.__value


from enum import Enum
import math
import string


class ElectricInductanceUnits(Enum):
        """
            ElectricInductanceUnits enumeration
        """
        
        Henry = 'henry'
        """
            
        """
        
        Picohenry = 'picohenry'
        """
            
        """
        
        Nanohenry = 'nanohenry'
        """
            
        """
        
        Microhenry = 'microhenry'
        """
            
        """
        
        Millihenry = 'millihenry'
        """
            
        """
        

class ElectricInductance:
    """
    Inductance is a property of an electrical conductor which opposes a change in current.

    Args:
        value (float): The value.
        from_unit (ElectricInductanceUnits): The ElectricInductance unit to create from, The default unit is Henry
    """
    def __init__(self, value: float, from_unit: ElectricInductanceUnits = ElectricInductanceUnits.Henry):
        if math.isnan(value):
            raise ValueError('Invalid unit: value is NaN')
        self.__value = self.__convert_to_base(value, from_unit)
        
        self.__henries = None
        
        self.__picohenries = None
        
        self.__nanohenries = None
        
        self.__microhenries = None
        
        self.__millihenries = None
        

    def __convert_from_base(self, from_unit: ElectricInductanceUnits) -> float:
        value = self.__value
        
        if from_unit == ElectricInductanceUnits.Henry:
            return (value)
        
        if from_unit == ElectricInductanceUnits.Picohenry:
            return ((value) / 1e-12)
        
        if from_unit == ElectricInductanceUnits.Nanohenry:
            return ((value) / 1e-09)
        
        if from_unit == ElectricInductanceUnits.Microhenry:
            return ((value) / 1e-06)
        
        if from_unit == ElectricInductanceUnits.Millihenry:
            return ((value) / 0.001)
        
        return None


    def __convert_to_base(self, value: float, to_unit: ElectricInductanceUnits) -> float:
        
        if to_unit == ElectricInductanceUnits.Henry:
            return (value)
        
        if to_unit == ElectricInductanceUnits.Picohenry:
            return ((value) * 1e-12)
        
        if to_unit == ElectricInductanceUnits.Nanohenry:
            return ((value) * 1e-09)
        
        if to_unit == ElectricInductanceUnits.Microhenry:
            return ((value) * 1e-06)
        
        if to_unit == ElectricInductanceUnits.Millihenry:
            return ((value) * 0.001)
        
        return None


    @property
    def base_value(self) -> float:
        return self.__value

    
    @staticmethod
    def from_henries(henries: float):
        """
        Create a new instance of ElectricInductance from a value in henries.

        

        :param meters: The ElectricInductance value in henries.
        :type henries: float
        :return: A new instance of ElectricInductance.
        :rtype: ElectricInductance
        """
        return ElectricInductance(henries, ElectricInductanceUnits.Henry)

    
    @staticmethod
    def from_picohenries(picohenries: float):
        """
        Create a new instance of ElectricInductance from a value in picohenries.

        

        :param meters: The ElectricInductance value in picohenries.
        :type picohenries: float
        :return: A new instance of ElectricInductance.
        :rtype: ElectricInductance
        """
        return ElectricInductance(picohenries, ElectricInductanceUnits.Picohenry)

    
    @staticmethod
    def from_nanohenries(nanohenries: float):
        """
        Create a new instance of ElectricInductance from a value in nanohenries.

        

        :param meters: The ElectricInductance value in nanohenries.
        :type nanohenries: float
        :return: A new instance of ElectricInductance.
        :rtype: ElectricInductance
        """
        return ElectricInductance(nanohenries, ElectricInductanceUnits.Nanohenry)

    
    @staticmethod
    def from_microhenries(microhenries: float):
        """
        Create a new instance of ElectricInductance from a value in microhenries.

        

        :param meters: The ElectricInductance value in microhenries.
        :type microhenries: float
        :return: A new instance of ElectricInductance.
        :rtype: ElectricInductance
        """
        return ElectricInductance(microhenries, ElectricInductanceUnits.Microhenry)

    
    @staticmethod
    def from_millihenries(millihenries: float):
        """
        Create a new instance of ElectricInductance from a value in millihenries.

        

        :param meters: The ElectricInductance value in millihenries.
        :type millihenries: float
        :return: A new instance of ElectricInductance.
        :rtype: ElectricInductance
        """
        return ElectricInductance(millihenries, ElectricInductanceUnits.Millihenry)

    
    @property
    def henries(self) -> float:
        """
        
        """
        if self.__henries != None:
            return self.__henries
        self.__henries = self.__convert_from_base(ElectricInductanceUnits.Henry)
        return self.__henries

    
    @property
    def picohenries(self) -> float:
        """
        
        """
        if self.__picohenries != None:
            return self.__picohenries
        self.__picohenries = self.__convert_from_base(ElectricInductanceUnits.Picohenry)
        return self.__picohenries

    
    @property
    def nanohenries(self) -> float:
        """
        
        """
        if self.__nanohenries != None:
            return self.__nanohenries
        self.__nanohenries = self.__convert_from_base(ElectricInductanceUnits.Nanohenry)
        return self.__nanohenries

    
    @property
    def microhenries(self) -> float:
        """
        
        """
        if self.__microhenries != None:
            return self.__microhenries
        self.__microhenries = self.__convert_from_base(ElectricInductanceUnits.Microhenry)
        return self.__microhenries

    
    @property
    def millihenries(self) -> float:
        """
        
        """
        if self.__millihenries != None:
            return self.__millihenries
        self.__millihenries = self.__convert_from_base(ElectricInductanceUnits.Millihenry)
        return self.__millihenries

    
    def to_string(self, unit: ElectricInductanceUnits = ElectricInductanceUnits.Henry) -> string:
        """
        Format the ElectricInductance to string.
        Note! the default format for ElectricInductance is Henry.
        To specify the unit format set the 'unit' parameter.
        """
        
        if unit == ElectricInductanceUnits.Henry:
            return f"""{self.henries} H"""
        
        if unit == ElectricInductanceUnits.Picohenry:
            return f"""{self.picohenries} """
        
        if unit == ElectricInductanceUnits.Nanohenry:
            return f"""{self.nanohenries} """
        
        if unit == ElectricInductanceUnits.Microhenry:
            return f"""{self.microhenries} """
        
        if unit == ElectricInductanceUnits.Millihenry:
            return f"""{self.millihenries} """
        
        return f'{self.__value}'


    def get_unit_abbreviation(self, unit_abbreviation: ElectricInductanceUnits = ElectricInductanceUnits.Henry) -> string:
        """
        Get ElectricInductance unit abbreviation.
        Note! the default abbreviation for ElectricInductance is Henry.
        To specify the unit abbreviation set the 'unit_abbreviation' parameter.
        """
        
        if unit_abbreviation == ElectricInductanceUnits.Henry:
            return """H"""
        
        if unit_abbreviation == ElectricInductanceUnits.Picohenry:
            return """"""
        
        if unit_abbreviation == ElectricInductanceUnits.Nanohenry:
            return """"""
        
        if unit_abbreviation == ElectricInductanceUnits.Microhenry:
            return """"""
        
        if unit_abbreviation == ElectricInductanceUnits.Millihenry:
            return """"""
        

    def __str__(self):
        return self.to_string()


    def __add__(self, other):
        if not isinstance(other, ElectricInductance):
            raise TypeError("unsupported operand type(s) for +: 'ElectricInductance' and '{}'".format(type(other).__name__))
        return ElectricInductance(self.__value + other.__value)


    def __mul__(self, other):
        if not isinstance(other, ElectricInductance):
            raise TypeError("unsupported operand type(s) for *: 'ElectricInductance' and '{}'".format(type(other).__name__))
        return ElectricInductance(self.__value * other.__value)


    def __sub__(self, other):
        if not isinstance(other, ElectricInductance):
            raise TypeError("unsupported operand type(s) for -: 'ElectricInductance' and '{}'".format(type(other).__name__))
        return ElectricInductance(self.__value - other.__value)


    def __truediv__(self, other):
        if not isinstance(other, ElectricInductance):
            raise TypeError("unsupported operand type(s) for /: 'ElectricInductance' and '{}'".format(type(other).__name__))
        return ElectricInductance(self.__value / other.__value)


    def __mod__(self, other):
        if not isinstance(other, ElectricInductance):
            raise TypeError("unsupported operand type(s) for %: 'ElectricInductance' and '{}'".format(type(other).__name__))
        return ElectricInductance(self.__value % other.__value)


    def __pow__(self, other):
        if not isinstance(other, ElectricInductance):
            raise TypeError("unsupported operand type(s) for **: 'ElectricInductance' and '{}'".format(type(other).__name__))
        return ElectricInductance(self.__value ** other.__value)


    def __eq__(self, other):
        if not isinstance(other, ElectricInductance):
            raise TypeError("unsupported operand type(s) for ==: 'ElectricInductance' and '{}'".format(type(other).__name__))
        return self.__value == other.__value


    def __lt__(self, other):
        if not isinstance(other, ElectricInductance):
            raise TypeError("unsupported operand type(s) for <: 'ElectricInductance' and '{}'".format(type(other).__name__))
        return self.__value < other.__value


    def __gt__(self, other):
        if not isinstance(other, ElectricInductance):
            raise TypeError("unsupported operand type(s) for >: 'ElectricInductance' and '{}'".format(type(other).__name__))
        return self.__value > other.__value


    def __le__(self, other):
        if not isinstance(other, ElectricInductance):
            raise TypeError("unsupported operand type(s) for <=: 'ElectricInductance' and '{}'".format(type(other).__name__))
        return self.__value <= other.__value


    def __ge__(self, other):
        if not isinstance(other, ElectricInductance):
            raise TypeError("unsupported operand type(s) for >=: 'ElectricInductance' and '{}'".format(type(other).__name__))
        return self.__value >= other.__value


from enum import Enum
import math
import string


class CoefficientOfThermalExpansionUnits(Enum):
        """
            CoefficientOfThermalExpansionUnits enumeration
        """
        
        PerKelvin = 'per_kelvin'
        """
            
        """
        
        PerDegreeCelsius = 'per_degree_celsius'
        """
            
        """
        
        PerDegreeFahrenheit = 'per_degree_fahrenheit'
        """
            
        """
        
        PpmPerKelvin = 'ppm_per_kelvin'
        """
            
        """
        
        PpmPerDegreeCelsius = 'ppm_per_degree_celsius'
        """
            
        """
        
        PpmPerDegreeFahrenheit = 'ppm_per_degree_fahrenheit'
        """
            
        """
        

class CoefficientOfThermalExpansion:
    """
    A unit that represents a fractional change in size in response to a change in temperature.

    Args:
        value (float): The value.
        from_unit (CoefficientOfThermalExpansionUnits): The CoefficientOfThermalExpansion unit to create from, The default unit is PerKelvin
    """
    def __init__(self, value: float, from_unit: CoefficientOfThermalExpansionUnits = CoefficientOfThermalExpansionUnits.PerKelvin):
        if math.isnan(value):
            raise ValueError('Invalid unit: value is NaN')
        self.__value = self.__convert_to_base(value, from_unit)
        
        self.__per_kelvin = None
        
        self.__per_degree_celsius = None
        
        self.__per_degree_fahrenheit = None
        
        self.__ppm_per_kelvin = None
        
        self.__ppm_per_degree_celsius = None
        
        self.__ppm_per_degree_fahrenheit = None
        

    def __convert_from_base(self, from_unit: CoefficientOfThermalExpansionUnits) -> float:
        value = self.__value
        
        if from_unit == CoefficientOfThermalExpansionUnits.PerKelvin:
            return (value)
        
        if from_unit == CoefficientOfThermalExpansionUnits.PerDegreeCelsius:
            return (value)
        
        if from_unit == CoefficientOfThermalExpansionUnits.PerDegreeFahrenheit:
            return (value * 5 / 9)
        
        if from_unit == CoefficientOfThermalExpansionUnits.PpmPerKelvin:
            return (value * 1e6)
        
        if from_unit == CoefficientOfThermalExpansionUnits.PpmPerDegreeCelsius:
            return (value * 1e6)
        
        if from_unit == CoefficientOfThermalExpansionUnits.PpmPerDegreeFahrenheit:
            return (value * 5e6 / 9)
        
        return None


    def __convert_to_base(self, value: float, to_unit: CoefficientOfThermalExpansionUnits) -> float:
        
        if to_unit == CoefficientOfThermalExpansionUnits.PerKelvin:
            return (value)
        
        if to_unit == CoefficientOfThermalExpansionUnits.PerDegreeCelsius:
            return (value)
        
        if to_unit == CoefficientOfThermalExpansionUnits.PerDegreeFahrenheit:
            return (value * 9 / 5)
        
        if to_unit == CoefficientOfThermalExpansionUnits.PpmPerKelvin:
            return (value / 1e6)
        
        if to_unit == CoefficientOfThermalExpansionUnits.PpmPerDegreeCelsius:
            return (value / 1e6)
        
        if to_unit == CoefficientOfThermalExpansionUnits.PpmPerDegreeFahrenheit:
            return (value * 9 / 5e6)
        
        return None


    @property
    def base_value(self) -> float:
        return self.__value

    
    @staticmethod
    def from_per_kelvin(per_kelvin: float):
        """
        Create a new instance of CoefficientOfThermalExpansion from a value in per_kelvin.

        

        :param meters: The CoefficientOfThermalExpansion value in per_kelvin.
        :type per_kelvin: float
        :return: A new instance of CoefficientOfThermalExpansion.
        :rtype: CoefficientOfThermalExpansion
        """
        return CoefficientOfThermalExpansion(per_kelvin, CoefficientOfThermalExpansionUnits.PerKelvin)

    
    @staticmethod
    def from_per_degree_celsius(per_degree_celsius: float):
        """
        Create a new instance of CoefficientOfThermalExpansion from a value in per_degree_celsius.

        

        :param meters: The CoefficientOfThermalExpansion value in per_degree_celsius.
        :type per_degree_celsius: float
        :return: A new instance of CoefficientOfThermalExpansion.
        :rtype: CoefficientOfThermalExpansion
        """
        return CoefficientOfThermalExpansion(per_degree_celsius, CoefficientOfThermalExpansionUnits.PerDegreeCelsius)

    
    @staticmethod
    def from_per_degree_fahrenheit(per_degree_fahrenheit: float):
        """
        Create a new instance of CoefficientOfThermalExpansion from a value in per_degree_fahrenheit.

        

        :param meters: The CoefficientOfThermalExpansion value in per_degree_fahrenheit.
        :type per_degree_fahrenheit: float
        :return: A new instance of CoefficientOfThermalExpansion.
        :rtype: CoefficientOfThermalExpansion
        """
        return CoefficientOfThermalExpansion(per_degree_fahrenheit, CoefficientOfThermalExpansionUnits.PerDegreeFahrenheit)

    
    @staticmethod
    def from_ppm_per_kelvin(ppm_per_kelvin: float):
        """
        Create a new instance of CoefficientOfThermalExpansion from a value in ppm_per_kelvin.

        

        :param meters: The CoefficientOfThermalExpansion value in ppm_per_kelvin.
        :type ppm_per_kelvin: float
        :return: A new instance of CoefficientOfThermalExpansion.
        :rtype: CoefficientOfThermalExpansion
        """
        return CoefficientOfThermalExpansion(ppm_per_kelvin, CoefficientOfThermalExpansionUnits.PpmPerKelvin)

    
    @staticmethod
    def from_ppm_per_degree_celsius(ppm_per_degree_celsius: float):
        """
        Create a new instance of CoefficientOfThermalExpansion from a value in ppm_per_degree_celsius.

        

        :param meters: The CoefficientOfThermalExpansion value in ppm_per_degree_celsius.
        :type ppm_per_degree_celsius: float
        :return: A new instance of CoefficientOfThermalExpansion.
        :rtype: CoefficientOfThermalExpansion
        """
        return CoefficientOfThermalExpansion(ppm_per_degree_celsius, CoefficientOfThermalExpansionUnits.PpmPerDegreeCelsius)

    
    @staticmethod
    def from_ppm_per_degree_fahrenheit(ppm_per_degree_fahrenheit: float):
        """
        Create a new instance of CoefficientOfThermalExpansion from a value in ppm_per_degree_fahrenheit.

        

        :param meters: The CoefficientOfThermalExpansion value in ppm_per_degree_fahrenheit.
        :type ppm_per_degree_fahrenheit: float
        :return: A new instance of CoefficientOfThermalExpansion.
        :rtype: CoefficientOfThermalExpansion
        """
        return CoefficientOfThermalExpansion(ppm_per_degree_fahrenheit, CoefficientOfThermalExpansionUnits.PpmPerDegreeFahrenheit)

    
    @property
    def per_kelvin(self) -> float:
        """
        
        """
        if self.__per_kelvin != None:
            return self.__per_kelvin
        self.__per_kelvin = self.__convert_from_base(CoefficientOfThermalExpansionUnits.PerKelvin)
        return self.__per_kelvin

    
    @property
    def per_degree_celsius(self) -> float:
        """
        
        """
        if self.__per_degree_celsius != None:
            return self.__per_degree_celsius
        self.__per_degree_celsius = self.__convert_from_base(CoefficientOfThermalExpansionUnits.PerDegreeCelsius)
        return self.__per_degree_celsius

    
    @property
    def per_degree_fahrenheit(self) -> float:
        """
        
        """
        if self.__per_degree_fahrenheit != None:
            return self.__per_degree_fahrenheit
        self.__per_degree_fahrenheit = self.__convert_from_base(CoefficientOfThermalExpansionUnits.PerDegreeFahrenheit)
        return self.__per_degree_fahrenheit

    
    @property
    def ppm_per_kelvin(self) -> float:
        """
        
        """
        if self.__ppm_per_kelvin != None:
            return self.__ppm_per_kelvin
        self.__ppm_per_kelvin = self.__convert_from_base(CoefficientOfThermalExpansionUnits.PpmPerKelvin)
        return self.__ppm_per_kelvin

    
    @property
    def ppm_per_degree_celsius(self) -> float:
        """
        
        """
        if self.__ppm_per_degree_celsius != None:
            return self.__ppm_per_degree_celsius
        self.__ppm_per_degree_celsius = self.__convert_from_base(CoefficientOfThermalExpansionUnits.PpmPerDegreeCelsius)
        return self.__ppm_per_degree_celsius

    
    @property
    def ppm_per_degree_fahrenheit(self) -> float:
        """
        
        """
        if self.__ppm_per_degree_fahrenheit != None:
            return self.__ppm_per_degree_fahrenheit
        self.__ppm_per_degree_fahrenheit = self.__convert_from_base(CoefficientOfThermalExpansionUnits.PpmPerDegreeFahrenheit)
        return self.__ppm_per_degree_fahrenheit

    
    def to_string(self, unit: CoefficientOfThermalExpansionUnits = CoefficientOfThermalExpansionUnits.PerKelvin) -> string:
        """
        Format the CoefficientOfThermalExpansion to string.
        Note! the default format for CoefficientOfThermalExpansion is PerKelvin.
        To specify the unit format set the 'unit' parameter.
        """
        
        if unit == CoefficientOfThermalExpansionUnits.PerKelvin:
            return f"""{self.per_kelvin} K⁻¹"""
        
        if unit == CoefficientOfThermalExpansionUnits.PerDegreeCelsius:
            return f"""{self.per_degree_celsius} °C⁻¹"""
        
        if unit == CoefficientOfThermalExpansionUnits.PerDegreeFahrenheit:
            return f"""{self.per_degree_fahrenheit} °F⁻¹"""
        
        if unit == CoefficientOfThermalExpansionUnits.PpmPerKelvin:
            return f"""{self.ppm_per_kelvin} ppm/K"""
        
        if unit == CoefficientOfThermalExpansionUnits.PpmPerDegreeCelsius:
            return f"""{self.ppm_per_degree_celsius} ppm/°C"""
        
        if unit == CoefficientOfThermalExpansionUnits.PpmPerDegreeFahrenheit:
            return f"""{self.ppm_per_degree_fahrenheit} ppm/°F"""
        
        return f'{self.__value}'


    def get_unit_abbreviation(self, unit_abbreviation: CoefficientOfThermalExpansionUnits = CoefficientOfThermalExpansionUnits.PerKelvin) -> string:
        """
        Get CoefficientOfThermalExpansion unit abbreviation.
        Note! the default abbreviation for CoefficientOfThermalExpansion is PerKelvin.
        To specify the unit abbreviation set the 'unit_abbreviation' parameter.
        """
        
        if unit_abbreviation == CoefficientOfThermalExpansionUnits.PerKelvin:
            return """K⁻¹"""
        
        if unit_abbreviation == CoefficientOfThermalExpansionUnits.PerDegreeCelsius:
            return """°C⁻¹"""
        
        if unit_abbreviation == CoefficientOfThermalExpansionUnits.PerDegreeFahrenheit:
            return """°F⁻¹"""
        
        if unit_abbreviation == CoefficientOfThermalExpansionUnits.PpmPerKelvin:
            return """ppm/K"""
        
        if unit_abbreviation == CoefficientOfThermalExpansionUnits.PpmPerDegreeCelsius:
            return """ppm/°C"""
        
        if unit_abbreviation == CoefficientOfThermalExpansionUnits.PpmPerDegreeFahrenheit:
            return """ppm/°F"""
        

    def __str__(self):
        return self.to_string()


    def __add__(self, other):
        if not isinstance(other, CoefficientOfThermalExpansion):
            raise TypeError("unsupported operand type(s) for +: 'CoefficientOfThermalExpansion' and '{}'".format(type(other).__name__))
        return CoefficientOfThermalExpansion(self.__value + other.__value)


    def __mul__(self, other):
        if not isinstance(other, CoefficientOfThermalExpansion):
            raise TypeError("unsupported operand type(s) for *: 'CoefficientOfThermalExpansion' and '{}'".format(type(other).__name__))
        return CoefficientOfThermalExpansion(self.__value * other.__value)


    def __sub__(self, other):
        if not isinstance(other, CoefficientOfThermalExpansion):
            raise TypeError("unsupported operand type(s) for -: 'CoefficientOfThermalExpansion' and '{}'".format(type(other).__name__))
        return CoefficientOfThermalExpansion(self.__value - other.__value)


    def __truediv__(self, other):
        if not isinstance(other, CoefficientOfThermalExpansion):
            raise TypeError("unsupported operand type(s) for /: 'CoefficientOfThermalExpansion' and '{}'".format(type(other).__name__))
        return CoefficientOfThermalExpansion(self.__value / other.__value)


    def __mod__(self, other):
        if not isinstance(other, CoefficientOfThermalExpansion):
            raise TypeError("unsupported operand type(s) for %: 'CoefficientOfThermalExpansion' and '{}'".format(type(other).__name__))
        return CoefficientOfThermalExpansion(self.__value % other.__value)


    def __pow__(self, other):
        if not isinstance(other, CoefficientOfThermalExpansion):
            raise TypeError("unsupported operand type(s) for **: 'CoefficientOfThermalExpansion' and '{}'".format(type(other).__name__))
        return CoefficientOfThermalExpansion(self.__value ** other.__value)


    def __eq__(self, other):
        if not isinstance(other, CoefficientOfThermalExpansion):
            raise TypeError("unsupported operand type(s) for ==: 'CoefficientOfThermalExpansion' and '{}'".format(type(other).__name__))
        return self.__value == other.__value


    def __lt__(self, other):
        if not isinstance(other, CoefficientOfThermalExpansion):
            raise TypeError("unsupported operand type(s) for <: 'CoefficientOfThermalExpansion' and '{}'".format(type(other).__name__))
        return self.__value < other.__value


    def __gt__(self, other):
        if not isinstance(other, CoefficientOfThermalExpansion):
            raise TypeError("unsupported operand type(s) for >: 'CoefficientOfThermalExpansion' and '{}'".format(type(other).__name__))
        return self.__value > other.__value


    def __le__(self, other):
        if not isinstance(other, CoefficientOfThermalExpansion):
            raise TypeError("unsupported operand type(s) for <=: 'CoefficientOfThermalExpansion' and '{}'".format(type(other).__name__))
        return self.__value <= other.__value


    def __ge__(self, other):
        if not isinstance(other, CoefficientOfThermalExpansion):
            raise TypeError("unsupported operand type(s) for >=: 'CoefficientOfThermalExpansion' and '{}'".format(type(other).__name__))
        return self.__value >= other.__value


from enum import Enum
import math
import string


class FrequencyUnits(Enum):
        """
            FrequencyUnits enumeration
        """
        
        Hertz = 'hertz'
        """
            
        """
        
        RadianPerSecond = 'radian_per_second'
        """
            
        """
        
        CyclePerMinute = 'cycle_per_minute'
        """
            
        """
        
        CyclePerHour = 'cycle_per_hour'
        """
            
        """
        
        BeatPerMinute = 'beat_per_minute'
        """
            
        """
        
        PerSecond = 'per_second'
        """
            
        """
        
        BUnit = 'b_unit'
        """
            
        """
        
        Microhertz = 'microhertz'
        """
            
        """
        
        Millihertz = 'millihertz'
        """
            
        """
        
        Kilohertz = 'kilohertz'
        """
            
        """
        
        Megahertz = 'megahertz'
        """
            
        """
        
        Gigahertz = 'gigahertz'
        """
            
        """
        
        Terahertz = 'terahertz'
        """
            
        """
        

class Frequency:
    """
    The number of occurrences of a repeating event per unit time.

    Args:
        value (float): The value.
        from_unit (FrequencyUnits): The Frequency unit to create from, The default unit is Hertz
    """
    def __init__(self, value: float, from_unit: FrequencyUnits = FrequencyUnits.Hertz):
        if math.isnan(value):
            raise ValueError('Invalid unit: value is NaN')
        self.__value = self.__convert_to_base(value, from_unit)
        
        self.__hertz = None
        
        self.__radians_per_second = None
        
        self.__cycles_per_minute = None
        
        self.__cycles_per_hour = None
        
        self.__beats_per_minute = None
        
        self.__per_second = None
        
        self.__b_units = None
        
        self.__microhertz = None
        
        self.__millihertz = None
        
        self.__kilohertz = None
        
        self.__megahertz = None
        
        self.__gigahertz = None
        
        self.__terahertz = None
        

    def __convert_from_base(self, from_unit: FrequencyUnits) -> float:
        value = self.__value
        
        if from_unit == FrequencyUnits.Hertz:
            return (value)
        
        if from_unit == FrequencyUnits.RadianPerSecond:
            return (value * 6.2831853072)
        
        if from_unit == FrequencyUnits.CyclePerMinute:
            return (value * 60)
        
        if from_unit == FrequencyUnits.CyclePerHour:
            return (value * 3600)
        
        if from_unit == FrequencyUnits.BeatPerMinute:
            return (value * 60)
        
        if from_unit == FrequencyUnits.PerSecond:
            return (value)
        
        if from_unit == FrequencyUnits.BUnit:
            return (value * value * 1e-3)
        
        if from_unit == FrequencyUnits.Microhertz:
            return ((value) / 1e-06)
        
        if from_unit == FrequencyUnits.Millihertz:
            return ((value) / 0.001)
        
        if from_unit == FrequencyUnits.Kilohertz:
            return ((value) / 1000.0)
        
        if from_unit == FrequencyUnits.Megahertz:
            return ((value) / 1000000.0)
        
        if from_unit == FrequencyUnits.Gigahertz:
            return ((value) / 1000000000.0)
        
        if from_unit == FrequencyUnits.Terahertz:
            return ((value) / 1000000000000.0)
        
        return None


    def __convert_to_base(self, value: float, to_unit: FrequencyUnits) -> float:
        
        if to_unit == FrequencyUnits.Hertz:
            return (value)
        
        if to_unit == FrequencyUnits.RadianPerSecond:
            return (value / 6.2831853072)
        
        if to_unit == FrequencyUnits.CyclePerMinute:
            return (value / 60)
        
        if to_unit == FrequencyUnits.CyclePerHour:
            return (value / 3600)
        
        if to_unit == FrequencyUnits.BeatPerMinute:
            return (value / 60)
        
        if to_unit == FrequencyUnits.PerSecond:
            return (value)
        
        if to_unit == FrequencyUnits.BUnit:
            return (math.sqrt(value * 1e3))
        
        if to_unit == FrequencyUnits.Microhertz:
            return ((value) * 1e-06)
        
        if to_unit == FrequencyUnits.Millihertz:
            return ((value) * 0.001)
        
        if to_unit == FrequencyUnits.Kilohertz:
            return ((value) * 1000.0)
        
        if to_unit == FrequencyUnits.Megahertz:
            return ((value) * 1000000.0)
        
        if to_unit == FrequencyUnits.Gigahertz:
            return ((value) * 1000000000.0)
        
        if to_unit == FrequencyUnits.Terahertz:
            return ((value) * 1000000000000.0)
        
        return None


    @property
    def base_value(self) -> float:
        return self.__value

    
    @staticmethod
    def from_hertz(hertz: float):
        """
        Create a new instance of Frequency from a value in hertz.

        

        :param meters: The Frequency value in hertz.
        :type hertz: float
        :return: A new instance of Frequency.
        :rtype: Frequency
        """
        return Frequency(hertz, FrequencyUnits.Hertz)

    
    @staticmethod
    def from_radians_per_second(radians_per_second: float):
        """
        Create a new instance of Frequency from a value in radians_per_second.

        

        :param meters: The Frequency value in radians_per_second.
        :type radians_per_second: float
        :return: A new instance of Frequency.
        :rtype: Frequency
        """
        return Frequency(radians_per_second, FrequencyUnits.RadianPerSecond)

    
    @staticmethod
    def from_cycles_per_minute(cycles_per_minute: float):
        """
        Create a new instance of Frequency from a value in cycles_per_minute.

        

        :param meters: The Frequency value in cycles_per_minute.
        :type cycles_per_minute: float
        :return: A new instance of Frequency.
        :rtype: Frequency
        """
        return Frequency(cycles_per_minute, FrequencyUnits.CyclePerMinute)

    
    @staticmethod
    def from_cycles_per_hour(cycles_per_hour: float):
        """
        Create a new instance of Frequency from a value in cycles_per_hour.

        

        :param meters: The Frequency value in cycles_per_hour.
        :type cycles_per_hour: float
        :return: A new instance of Frequency.
        :rtype: Frequency
        """
        return Frequency(cycles_per_hour, FrequencyUnits.CyclePerHour)

    
    @staticmethod
    def from_beats_per_minute(beats_per_minute: float):
        """
        Create a new instance of Frequency from a value in beats_per_minute.

        

        :param meters: The Frequency value in beats_per_minute.
        :type beats_per_minute: float
        :return: A new instance of Frequency.
        :rtype: Frequency
        """
        return Frequency(beats_per_minute, FrequencyUnits.BeatPerMinute)

    
    @staticmethod
    def from_per_second(per_second: float):
        """
        Create a new instance of Frequency from a value in per_second.

        

        :param meters: The Frequency value in per_second.
        :type per_second: float
        :return: A new instance of Frequency.
        :rtype: Frequency
        """
        return Frequency(per_second, FrequencyUnits.PerSecond)

    
    @staticmethod
    def from_b_units(b_units: float):
        """
        Create a new instance of Frequency from a value in b_units.

        

        :param meters: The Frequency value in b_units.
        :type b_units: float
        :return: A new instance of Frequency.
        :rtype: Frequency
        """
        return Frequency(b_units, FrequencyUnits.BUnit)

    
    @staticmethod
    def from_microhertz(microhertz: float):
        """
        Create a new instance of Frequency from a value in microhertz.

        

        :param meters: The Frequency value in microhertz.
        :type microhertz: float
        :return: A new instance of Frequency.
        :rtype: Frequency
        """
        return Frequency(microhertz, FrequencyUnits.Microhertz)

    
    @staticmethod
    def from_millihertz(millihertz: float):
        """
        Create a new instance of Frequency from a value in millihertz.

        

        :param meters: The Frequency value in millihertz.
        :type millihertz: float
        :return: A new instance of Frequency.
        :rtype: Frequency
        """
        return Frequency(millihertz, FrequencyUnits.Millihertz)

    
    @staticmethod
    def from_kilohertz(kilohertz: float):
        """
        Create a new instance of Frequency from a value in kilohertz.

        

        :param meters: The Frequency value in kilohertz.
        :type kilohertz: float
        :return: A new instance of Frequency.
        :rtype: Frequency
        """
        return Frequency(kilohertz, FrequencyUnits.Kilohertz)

    
    @staticmethod
    def from_megahertz(megahertz: float):
        """
        Create a new instance of Frequency from a value in megahertz.

        

        :param meters: The Frequency value in megahertz.
        :type megahertz: float
        :return: A new instance of Frequency.
        :rtype: Frequency
        """
        return Frequency(megahertz, FrequencyUnits.Megahertz)

    
    @staticmethod
    def from_gigahertz(gigahertz: float):
        """
        Create a new instance of Frequency from a value in gigahertz.

        

        :param meters: The Frequency value in gigahertz.
        :type gigahertz: float
        :return: A new instance of Frequency.
        :rtype: Frequency
        """
        return Frequency(gigahertz, FrequencyUnits.Gigahertz)

    
    @staticmethod
    def from_terahertz(terahertz: float):
        """
        Create a new instance of Frequency from a value in terahertz.

        

        :param meters: The Frequency value in terahertz.
        :type terahertz: float
        :return: A new instance of Frequency.
        :rtype: Frequency
        """
        return Frequency(terahertz, FrequencyUnits.Terahertz)

    
    @property
    def hertz(self) -> float:
        """
        
        """
        if self.__hertz != None:
            return self.__hertz
        self.__hertz = self.__convert_from_base(FrequencyUnits.Hertz)
        return self.__hertz

    
    @property
    def radians_per_second(self) -> float:
        """
        
        """
        if self.__radians_per_second != None:
            return self.__radians_per_second
        self.__radians_per_second = self.__convert_from_base(FrequencyUnits.RadianPerSecond)
        return self.__radians_per_second

    
    @property
    def cycles_per_minute(self) -> float:
        """
        
        """
        if self.__cycles_per_minute != None:
            return self.__cycles_per_minute
        self.__cycles_per_minute = self.__convert_from_base(FrequencyUnits.CyclePerMinute)
        return self.__cycles_per_minute

    
    @property
    def cycles_per_hour(self) -> float:
        """
        
        """
        if self.__cycles_per_hour != None:
            return self.__cycles_per_hour
        self.__cycles_per_hour = self.__convert_from_base(FrequencyUnits.CyclePerHour)
        return self.__cycles_per_hour

    
    @property
    def beats_per_minute(self) -> float:
        """
        
        """
        if self.__beats_per_minute != None:
            return self.__beats_per_minute
        self.__beats_per_minute = self.__convert_from_base(FrequencyUnits.BeatPerMinute)
        return self.__beats_per_minute

    
    @property
    def per_second(self) -> float:
        """
        
        """
        if self.__per_second != None:
            return self.__per_second
        self.__per_second = self.__convert_from_base(FrequencyUnits.PerSecond)
        return self.__per_second

    
    @property
    def b_units(self) -> float:
        """
        
        """
        if self.__b_units != None:
            return self.__b_units
        self.__b_units = self.__convert_from_base(FrequencyUnits.BUnit)
        return self.__b_units

    
    @property
    def microhertz(self) -> float:
        """
        
        """
        if self.__microhertz != None:
            return self.__microhertz
        self.__microhertz = self.__convert_from_base(FrequencyUnits.Microhertz)
        return self.__microhertz

    
    @property
    def millihertz(self) -> float:
        """
        
        """
        if self.__millihertz != None:
            return self.__millihertz
        self.__millihertz = self.__convert_from_base(FrequencyUnits.Millihertz)
        return self.__millihertz

    
    @property
    def kilohertz(self) -> float:
        """
        
        """
        if self.__kilohertz != None:
            return self.__kilohertz
        self.__kilohertz = self.__convert_from_base(FrequencyUnits.Kilohertz)
        return self.__kilohertz

    
    @property
    def megahertz(self) -> float:
        """
        
        """
        if self.__megahertz != None:
            return self.__megahertz
        self.__megahertz = self.__convert_from_base(FrequencyUnits.Megahertz)
        return self.__megahertz

    
    @property
    def gigahertz(self) -> float:
        """
        
        """
        if self.__gigahertz != None:
            return self.__gigahertz
        self.__gigahertz = self.__convert_from_base(FrequencyUnits.Gigahertz)
        return self.__gigahertz

    
    @property
    def terahertz(self) -> float:
        """
        
        """
        if self.__terahertz != None:
            return self.__terahertz
        self.__terahertz = self.__convert_from_base(FrequencyUnits.Terahertz)
        return self.__terahertz

    
    def to_string(self, unit: FrequencyUnits = FrequencyUnits.Hertz) -> string:
        """
        Format the Frequency to string.
        Note! the default format for Frequency is Hertz.
        To specify the unit format set the 'unit' parameter.
        """
        
        if unit == FrequencyUnits.Hertz:
            return f"""{self.hertz} Hz"""
        
        if unit == FrequencyUnits.RadianPerSecond:
            return f"""{self.radians_per_second} rad/s"""
        
        if unit == FrequencyUnits.CyclePerMinute:
            return f"""{self.cycles_per_minute} cpm"""
        
        if unit == FrequencyUnits.CyclePerHour:
            return f"""{self.cycles_per_hour} cph"""
        
        if unit == FrequencyUnits.BeatPerMinute:
            return f"""{self.beats_per_minute} bpm"""
        
        if unit == FrequencyUnits.PerSecond:
            return f"""{self.per_second} s⁻¹"""
        
        if unit == FrequencyUnits.BUnit:
            return f"""{self.b_units} B Units"""
        
        if unit == FrequencyUnits.Microhertz:
            return f"""{self.microhertz} """
        
        if unit == FrequencyUnits.Millihertz:
            return f"""{self.millihertz} """
        
        if unit == FrequencyUnits.Kilohertz:
            return f"""{self.kilohertz} """
        
        if unit == FrequencyUnits.Megahertz:
            return f"""{self.megahertz} """
        
        if unit == FrequencyUnits.Gigahertz:
            return f"""{self.gigahertz} """
        
        if unit == FrequencyUnits.Terahertz:
            return f"""{self.terahertz} """
        
        return f'{self.__value}'


    def get_unit_abbreviation(self, unit_abbreviation: FrequencyUnits = FrequencyUnits.Hertz) -> string:
        """
        Get Frequency unit abbreviation.
        Note! the default abbreviation for Frequency is Hertz.
        To specify the unit abbreviation set the 'unit_abbreviation' parameter.
        """
        
        if unit_abbreviation == FrequencyUnits.Hertz:
            return """Hz"""
        
        if unit_abbreviation == FrequencyUnits.RadianPerSecond:
            return """rad/s"""
        
        if unit_abbreviation == FrequencyUnits.CyclePerMinute:
            return """cpm"""
        
        if unit_abbreviation == FrequencyUnits.CyclePerHour:
            return """cph"""
        
        if unit_abbreviation == FrequencyUnits.BeatPerMinute:
            return """bpm"""
        
        if unit_abbreviation == FrequencyUnits.PerSecond:
            return """s⁻¹"""
        
        if unit_abbreviation == FrequencyUnits.BUnit:
            return """B Units"""
        
        if unit_abbreviation == FrequencyUnits.Microhertz:
            return """"""
        
        if unit_abbreviation == FrequencyUnits.Millihertz:
            return """"""
        
        if unit_abbreviation == FrequencyUnits.Kilohertz:
            return """"""
        
        if unit_abbreviation == FrequencyUnits.Megahertz:
            return """"""
        
        if unit_abbreviation == FrequencyUnits.Gigahertz:
            return """"""
        
        if unit_abbreviation == FrequencyUnits.Terahertz:
            return """"""
        

    def __str__(self):
        return self.to_string()


    def __add__(self, other):
        if not isinstance(other, Frequency):
            raise TypeError("unsupported operand type(s) for +: 'Frequency' and '{}'".format(type(other).__name__))
        return Frequency(self.__value + other.__value)


    def __mul__(self, other):
        if not isinstance(other, Frequency):
            raise TypeError("unsupported operand type(s) for *: 'Frequency' and '{}'".format(type(other).__name__))
        return Frequency(self.__value * other.__value)


    def __sub__(self, other):
        if not isinstance(other, Frequency):
            raise TypeError("unsupported operand type(s) for -: 'Frequency' and '{}'".format(type(other).__name__))
        return Frequency(self.__value - other.__value)


    def __truediv__(self, other):
        if not isinstance(other, Frequency):
            raise TypeError("unsupported operand type(s) for /: 'Frequency' and '{}'".format(type(other).__name__))
        return Frequency(self.__value / other.__value)


    def __mod__(self, other):
        if not isinstance(other, Frequency):
            raise TypeError("unsupported operand type(s) for %: 'Frequency' and '{}'".format(type(other).__name__))
        return Frequency(self.__value % other.__value)


    def __pow__(self, other):
        if not isinstance(other, Frequency):
            raise TypeError("unsupported operand type(s) for **: 'Frequency' and '{}'".format(type(other).__name__))
        return Frequency(self.__value ** other.__value)


    def __eq__(self, other):
        if not isinstance(other, Frequency):
            raise TypeError("unsupported operand type(s) for ==: 'Frequency' and '{}'".format(type(other).__name__))
        return self.__value == other.__value


    def __lt__(self, other):
        if not isinstance(other, Frequency):
            raise TypeError("unsupported operand type(s) for <: 'Frequency' and '{}'".format(type(other).__name__))
        return self.__value < other.__value


    def __gt__(self, other):
        if not isinstance(other, Frequency):
            raise TypeError("unsupported operand type(s) for >: 'Frequency' and '{}'".format(type(other).__name__))
        return self.__value > other.__value


    def __le__(self, other):
        if not isinstance(other, Frequency):
            raise TypeError("unsupported operand type(s) for <=: 'Frequency' and '{}'".format(type(other).__name__))
        return self.__value <= other.__value


    def __ge__(self, other):
        if not isinstance(other, Frequency):
            raise TypeError("unsupported operand type(s) for >=: 'Frequency' and '{}'".format(type(other).__name__))
        return self.__value >= other.__value


from enum import Enum
import math
import string


class ElectricSurfaceChargeDensityUnits(Enum):
        """
            ElectricSurfaceChargeDensityUnits enumeration
        """
        
        CoulombPerSquareMeter = 'coulomb_per_square_meter'
        """
            
        """
        
        CoulombPerSquareCentimeter = 'coulomb_per_square_centimeter'
        """
            
        """
        
        CoulombPerSquareInch = 'coulomb_per_square_inch'
        """
            
        """
        

class ElectricSurfaceChargeDensity:
    """
    In electromagnetism, surface charge density is a measure of the amount of electric charge per surface area.

    Args:
        value (float): The value.
        from_unit (ElectricSurfaceChargeDensityUnits): The ElectricSurfaceChargeDensity unit to create from, The default unit is CoulombPerSquareMeter
    """
    def __init__(self, value: float, from_unit: ElectricSurfaceChargeDensityUnits = ElectricSurfaceChargeDensityUnits.CoulombPerSquareMeter):
        if math.isnan(value):
            raise ValueError('Invalid unit: value is NaN')
        self.__value = self.__convert_to_base(value, from_unit)
        
        self.__coulombs_per_square_meter = None
        
        self.__coulombs_per_square_centimeter = None
        
        self.__coulombs_per_square_inch = None
        

    def __convert_from_base(self, from_unit: ElectricSurfaceChargeDensityUnits) -> float:
        value = self.__value
        
        if from_unit == ElectricSurfaceChargeDensityUnits.CoulombPerSquareMeter:
            return (value)
        
        if from_unit == ElectricSurfaceChargeDensityUnits.CoulombPerSquareCentimeter:
            return (value / 1.0e4)
        
        if from_unit == ElectricSurfaceChargeDensityUnits.CoulombPerSquareInch:
            return (value / 1.5500031000062000e3)
        
        return None


    def __convert_to_base(self, value: float, to_unit: ElectricSurfaceChargeDensityUnits) -> float:
        
        if to_unit == ElectricSurfaceChargeDensityUnits.CoulombPerSquareMeter:
            return (value)
        
        if to_unit == ElectricSurfaceChargeDensityUnits.CoulombPerSquareCentimeter:
            return (value * 1.0e4)
        
        if to_unit == ElectricSurfaceChargeDensityUnits.CoulombPerSquareInch:
            return (value * 1.5500031000062000e3)
        
        return None


    @property
    def base_value(self) -> float:
        return self.__value

    
    @staticmethod
    def from_coulombs_per_square_meter(coulombs_per_square_meter: float):
        """
        Create a new instance of ElectricSurfaceChargeDensity from a value in coulombs_per_square_meter.

        

        :param meters: The ElectricSurfaceChargeDensity value in coulombs_per_square_meter.
        :type coulombs_per_square_meter: float
        :return: A new instance of ElectricSurfaceChargeDensity.
        :rtype: ElectricSurfaceChargeDensity
        """
        return ElectricSurfaceChargeDensity(coulombs_per_square_meter, ElectricSurfaceChargeDensityUnits.CoulombPerSquareMeter)

    
    @staticmethod
    def from_coulombs_per_square_centimeter(coulombs_per_square_centimeter: float):
        """
        Create a new instance of ElectricSurfaceChargeDensity from a value in coulombs_per_square_centimeter.

        

        :param meters: The ElectricSurfaceChargeDensity value in coulombs_per_square_centimeter.
        :type coulombs_per_square_centimeter: float
        :return: A new instance of ElectricSurfaceChargeDensity.
        :rtype: ElectricSurfaceChargeDensity
        """
        return ElectricSurfaceChargeDensity(coulombs_per_square_centimeter, ElectricSurfaceChargeDensityUnits.CoulombPerSquareCentimeter)

    
    @staticmethod
    def from_coulombs_per_square_inch(coulombs_per_square_inch: float):
        """
        Create a new instance of ElectricSurfaceChargeDensity from a value in coulombs_per_square_inch.

        

        :param meters: The ElectricSurfaceChargeDensity value in coulombs_per_square_inch.
        :type coulombs_per_square_inch: float
        :return: A new instance of ElectricSurfaceChargeDensity.
        :rtype: ElectricSurfaceChargeDensity
        """
        return ElectricSurfaceChargeDensity(coulombs_per_square_inch, ElectricSurfaceChargeDensityUnits.CoulombPerSquareInch)

    
    @property
    def coulombs_per_square_meter(self) -> float:
        """
        
        """
        if self.__coulombs_per_square_meter != None:
            return self.__coulombs_per_square_meter
        self.__coulombs_per_square_meter = self.__convert_from_base(ElectricSurfaceChargeDensityUnits.CoulombPerSquareMeter)
        return self.__coulombs_per_square_meter

    
    @property
    def coulombs_per_square_centimeter(self) -> float:
        """
        
        """
        if self.__coulombs_per_square_centimeter != None:
            return self.__coulombs_per_square_centimeter
        self.__coulombs_per_square_centimeter = self.__convert_from_base(ElectricSurfaceChargeDensityUnits.CoulombPerSquareCentimeter)
        return self.__coulombs_per_square_centimeter

    
    @property
    def coulombs_per_square_inch(self) -> float:
        """
        
        """
        if self.__coulombs_per_square_inch != None:
            return self.__coulombs_per_square_inch
        self.__coulombs_per_square_inch = self.__convert_from_base(ElectricSurfaceChargeDensityUnits.CoulombPerSquareInch)
        return self.__coulombs_per_square_inch

    
    def to_string(self, unit: ElectricSurfaceChargeDensityUnits = ElectricSurfaceChargeDensityUnits.CoulombPerSquareMeter) -> string:
        """
        Format the ElectricSurfaceChargeDensity to string.
        Note! the default format for ElectricSurfaceChargeDensity is CoulombPerSquareMeter.
        To specify the unit format set the 'unit' parameter.
        """
        
        if unit == ElectricSurfaceChargeDensityUnits.CoulombPerSquareMeter:
            return f"""{self.coulombs_per_square_meter} C/m²"""
        
        if unit == ElectricSurfaceChargeDensityUnits.CoulombPerSquareCentimeter:
            return f"""{self.coulombs_per_square_centimeter} C/cm²"""
        
        if unit == ElectricSurfaceChargeDensityUnits.CoulombPerSquareInch:
            return f"""{self.coulombs_per_square_inch} C/in²"""
        
        return f'{self.__value}'


    def get_unit_abbreviation(self, unit_abbreviation: ElectricSurfaceChargeDensityUnits = ElectricSurfaceChargeDensityUnits.CoulombPerSquareMeter) -> string:
        """
        Get ElectricSurfaceChargeDensity unit abbreviation.
        Note! the default abbreviation for ElectricSurfaceChargeDensity is CoulombPerSquareMeter.
        To specify the unit abbreviation set the 'unit_abbreviation' parameter.
        """
        
        if unit_abbreviation == ElectricSurfaceChargeDensityUnits.CoulombPerSquareMeter:
            return """C/m²"""
        
        if unit_abbreviation == ElectricSurfaceChargeDensityUnits.CoulombPerSquareCentimeter:
            return """C/cm²"""
        
        if unit_abbreviation == ElectricSurfaceChargeDensityUnits.CoulombPerSquareInch:
            return """C/in²"""
        

    def __str__(self):
        return self.to_string()


    def __add__(self, other):
        if not isinstance(other, ElectricSurfaceChargeDensity):
            raise TypeError("unsupported operand type(s) for +: 'ElectricSurfaceChargeDensity' and '{}'".format(type(other).__name__))
        return ElectricSurfaceChargeDensity(self.__value + other.__value)


    def __mul__(self, other):
        if not isinstance(other, ElectricSurfaceChargeDensity):
            raise TypeError("unsupported operand type(s) for *: 'ElectricSurfaceChargeDensity' and '{}'".format(type(other).__name__))
        return ElectricSurfaceChargeDensity(self.__value * other.__value)


    def __sub__(self, other):
        if not isinstance(other, ElectricSurfaceChargeDensity):
            raise TypeError("unsupported operand type(s) for -: 'ElectricSurfaceChargeDensity' and '{}'".format(type(other).__name__))
        return ElectricSurfaceChargeDensity(self.__value - other.__value)


    def __truediv__(self, other):
        if not isinstance(other, ElectricSurfaceChargeDensity):
            raise TypeError("unsupported operand type(s) for /: 'ElectricSurfaceChargeDensity' and '{}'".format(type(other).__name__))
        return ElectricSurfaceChargeDensity(self.__value / other.__value)


    def __mod__(self, other):
        if not isinstance(other, ElectricSurfaceChargeDensity):
            raise TypeError("unsupported operand type(s) for %: 'ElectricSurfaceChargeDensity' and '{}'".format(type(other).__name__))
        return ElectricSurfaceChargeDensity(self.__value % other.__value)


    def __pow__(self, other):
        if not isinstance(other, ElectricSurfaceChargeDensity):
            raise TypeError("unsupported operand type(s) for **: 'ElectricSurfaceChargeDensity' and '{}'".format(type(other).__name__))
        return ElectricSurfaceChargeDensity(self.__value ** other.__value)


    def __eq__(self, other):
        if not isinstance(other, ElectricSurfaceChargeDensity):
            raise TypeError("unsupported operand type(s) for ==: 'ElectricSurfaceChargeDensity' and '{}'".format(type(other).__name__))
        return self.__value == other.__value


    def __lt__(self, other):
        if not isinstance(other, ElectricSurfaceChargeDensity):
            raise TypeError("unsupported operand type(s) for <: 'ElectricSurfaceChargeDensity' and '{}'".format(type(other).__name__))
        return self.__value < other.__value


    def __gt__(self, other):
        if not isinstance(other, ElectricSurfaceChargeDensity):
            raise TypeError("unsupported operand type(s) for >: 'ElectricSurfaceChargeDensity' and '{}'".format(type(other).__name__))
        return self.__value > other.__value


    def __le__(self, other):
        if not isinstance(other, ElectricSurfaceChargeDensity):
            raise TypeError("unsupported operand type(s) for <=: 'ElectricSurfaceChargeDensity' and '{}'".format(type(other).__name__))
        return self.__value <= other.__value


    def __ge__(self, other):
        if not isinstance(other, ElectricSurfaceChargeDensity):
            raise TypeError("unsupported operand type(s) for >=: 'ElectricSurfaceChargeDensity' and '{}'".format(type(other).__name__))
        return self.__value >= other.__value


# -*- coding: utf-8 -*-
from setuptools import setup
from pathlib import Path
this_directory = Path(__file__).parent
long_description = (this_directory / "README.md").read_text()

packages = \
['unitsnet_py', 'unitsnet_py.units']

package_data = \
{'': ['*']}

setup_kwargs = {
    'name': 'unitsnet-py',
    'version': '0.1.49',
    'keywords': 'conversion, units-of-measure, units, quantities, unit-converter, converter, unit, measure, measures, measurement, measurements',
    'description': 'A better way to hold unit variables and easily convert to the destination unit',
    'long_description': long_description,
    'long_description_content_type': "text/markdown",
    'author': 'Haim Kastner',
    'author_email': 'haim.kastner@gmail.com',
    'maintainer': 'Haim Kastner',
    'maintainer_email': 'haim.kastner@gmail.com',
    'url': 'https://github.com/haimkastner/unitsnet-py',
    'packages': packages,
    'package_data': package_data,
    'python_requires': '>=3.10,<4.0',
}


setup(**setup_kwargs)




from enum import Enum
import math
import string


class ElectricConductivityUnits(Enum):
        """
            ElectricConductivityUnits enumeration
        """
        
        SiemensPerMeter = 'siemens_per_meter'
        """
            
        """
        
        SiemensPerInch = 'siemens_per_inch'
        """
            
        """
        
        SiemensPerFoot = 'siemens_per_foot'
        """
            
        """
        
        SiemensPerCentimeter = 'siemens_per_centimeter'
        """
            
        """
        
        MicrosiemensPerCentimeter = 'microsiemens_per_centimeter'
        """
            
        """
        
        MillisiemensPerCentimeter = 'millisiemens_per_centimeter'
        """
            
        """
        

class ElectricConductivity:
    """
    Electrical conductivity or specific conductance is the reciprocal of electrical resistivity, and measures a material's ability to conduct an electric current.

    Args:
        value (float): The value.
        from_unit (ElectricConductivityUnits): The ElectricConductivity unit to create from, The default unit is SiemensPerMeter
    """
    def __init__(self, value: float, from_unit: ElectricConductivityUnits = ElectricConductivityUnits.SiemensPerMeter):
        if math.isnan(value):
            raise ValueError('Invalid unit: value is NaN')
        self.__value = self.__convert_to_base(value, from_unit)
        
        self.__siemens_per_meter = None
        
        self.__siemens_per_inch = None
        
        self.__siemens_per_foot = None
        
        self.__siemens_per_centimeter = None
        
        self.__microsiemens_per_centimeter = None
        
        self.__millisiemens_per_centimeter = None
        

    def __convert_from_base(self, from_unit: ElectricConductivityUnits) -> float:
        value = self.__value
        
        if from_unit == ElectricConductivityUnits.SiemensPerMeter:
            return (value)
        
        if from_unit == ElectricConductivityUnits.SiemensPerInch:
            return (value / 3.937007874015748e1)
        
        if from_unit == ElectricConductivityUnits.SiemensPerFoot:
            return (value / 3.2808398950131234)
        
        if from_unit == ElectricConductivityUnits.SiemensPerCentimeter:
            return (value / 1e2)
        
        if from_unit == ElectricConductivityUnits.MicrosiemensPerCentimeter:
            return ((value / 1e2) / 1e-06)
        
        if from_unit == ElectricConductivityUnits.MillisiemensPerCentimeter:
            return ((value / 1e2) / 0.001)
        
        return None


    def __convert_to_base(self, value: float, to_unit: ElectricConductivityUnits) -> float:
        
        if to_unit == ElectricConductivityUnits.SiemensPerMeter:
            return (value)
        
        if to_unit == ElectricConductivityUnits.SiemensPerInch:
            return (value * 3.937007874015748e1)
        
        if to_unit == ElectricConductivityUnits.SiemensPerFoot:
            return (value * 3.2808398950131234)
        
        if to_unit == ElectricConductivityUnits.SiemensPerCentimeter:
            return (value * 1e2)
        
        if to_unit == ElectricConductivityUnits.MicrosiemensPerCentimeter:
            return ((value * 1e2) * 1e-06)
        
        if to_unit == ElectricConductivityUnits.MillisiemensPerCentimeter:
            return ((value * 1e2) * 0.001)
        
        return None


    @property
    def base_value(self) -> float:
        return self.__value

    
    @staticmethod
    def from_siemens_per_meter(siemens_per_meter: float):
        """
        Create a new instance of ElectricConductivity from a value in siemens_per_meter.

        

        :param meters: The ElectricConductivity value in siemens_per_meter.
        :type siemens_per_meter: float
        :return: A new instance of ElectricConductivity.
        :rtype: ElectricConductivity
        """
        return ElectricConductivity(siemens_per_meter, ElectricConductivityUnits.SiemensPerMeter)

    
    @staticmethod
    def from_siemens_per_inch(siemens_per_inch: float):
        """
        Create a new instance of ElectricConductivity from a value in siemens_per_inch.

        

        :param meters: The ElectricConductivity value in siemens_per_inch.
        :type siemens_per_inch: float
        :return: A new instance of ElectricConductivity.
        :rtype: ElectricConductivity
        """
        return ElectricConductivity(siemens_per_inch, ElectricConductivityUnits.SiemensPerInch)

    
    @staticmethod
    def from_siemens_per_foot(siemens_per_foot: float):
        """
        Create a new instance of ElectricConductivity from a value in siemens_per_foot.

        

        :param meters: The ElectricConductivity value in siemens_per_foot.
        :type siemens_per_foot: float
        :return: A new instance of ElectricConductivity.
        :rtype: ElectricConductivity
        """
        return ElectricConductivity(siemens_per_foot, ElectricConductivityUnits.SiemensPerFoot)

    
    @staticmethod
    def from_siemens_per_centimeter(siemens_per_centimeter: float):
        """
        Create a new instance of ElectricConductivity from a value in siemens_per_centimeter.

        

        :param meters: The ElectricConductivity value in siemens_per_centimeter.
        :type siemens_per_centimeter: float
        :return: A new instance of ElectricConductivity.
        :rtype: ElectricConductivity
        """
        return ElectricConductivity(siemens_per_centimeter, ElectricConductivityUnits.SiemensPerCentimeter)

    
    @staticmethod
    def from_microsiemens_per_centimeter(microsiemens_per_centimeter: float):
        """
        Create a new instance of ElectricConductivity from a value in microsiemens_per_centimeter.

        

        :param meters: The ElectricConductivity value in microsiemens_per_centimeter.
        :type microsiemens_per_centimeter: float
        :return: A new instance of ElectricConductivity.
        :rtype: ElectricConductivity
        """
        return ElectricConductivity(microsiemens_per_centimeter, ElectricConductivityUnits.MicrosiemensPerCentimeter)

    
    @staticmethod
    def from_millisiemens_per_centimeter(millisiemens_per_centimeter: float):
        """
        Create a new instance of ElectricConductivity from a value in millisiemens_per_centimeter.

        

        :param meters: The ElectricConductivity value in millisiemens_per_centimeter.
        :type millisiemens_per_centimeter: float
        :return: A new instance of ElectricConductivity.
        :rtype: ElectricConductivity
        """
        return ElectricConductivity(millisiemens_per_centimeter, ElectricConductivityUnits.MillisiemensPerCentimeter)

    
    @property
    def siemens_per_meter(self) -> float:
        """
        
        """
        if self.__siemens_per_meter != None:
            return self.__siemens_per_meter
        self.__siemens_per_meter = self.__convert_from_base(ElectricConductivityUnits.SiemensPerMeter)
        return self.__siemens_per_meter

    
    @property
    def siemens_per_inch(self) -> float:
        """
        
        """
        if self.__siemens_per_inch != None:
            return self.__siemens_per_inch
        self.__siemens_per_inch = self.__convert_from_base(ElectricConductivityUnits.SiemensPerInch)
        return self.__siemens_per_inch

    
    @property
    def siemens_per_foot(self) -> float:
        """
        
        """
        if self.__siemens_per_foot != None:
            return self.__siemens_per_foot
        self.__siemens_per_foot = self.__convert_from_base(ElectricConductivityUnits.SiemensPerFoot)
        return self.__siemens_per_foot

    
    @property
    def siemens_per_centimeter(self) -> float:
        """
        
        """
        if self.__siemens_per_centimeter != None:
            return self.__siemens_per_centimeter
        self.__siemens_per_centimeter = self.__convert_from_base(ElectricConductivityUnits.SiemensPerCentimeter)
        return self.__siemens_per_centimeter

    
    @property
    def microsiemens_per_centimeter(self) -> float:
        """
        
        """
        if self.__microsiemens_per_centimeter != None:
            return self.__microsiemens_per_centimeter
        self.__microsiemens_per_centimeter = self.__convert_from_base(ElectricConductivityUnits.MicrosiemensPerCentimeter)
        return self.__microsiemens_per_centimeter

    
    @property
    def millisiemens_per_centimeter(self) -> float:
        """
        
        """
        if self.__millisiemens_per_centimeter != None:
            return self.__millisiemens_per_centimeter
        self.__millisiemens_per_centimeter = self.__convert_from_base(ElectricConductivityUnits.MillisiemensPerCentimeter)
        return self.__millisiemens_per_centimeter

    
    def to_string(self, unit: ElectricConductivityUnits = ElectricConductivityUnits.SiemensPerMeter) -> string:
        """
        Format the ElectricConductivity to string.
        Note! the default format for ElectricConductivity is SiemensPerMeter.
        To specify the unit format set the 'unit' parameter.
        """
        
        if unit == ElectricConductivityUnits.SiemensPerMeter:
            return f"""{self.siemens_per_meter} S/m"""
        
        if unit == ElectricConductivityUnits.SiemensPerInch:
            return f"""{self.siemens_per_inch} S/in"""
        
        if unit == ElectricConductivityUnits.SiemensPerFoot:
            return f"""{self.siemens_per_foot} S/ft"""
        
        if unit == ElectricConductivityUnits.SiemensPerCentimeter:
            return f"""{self.siemens_per_centimeter} S/cm"""
        
        if unit == ElectricConductivityUnits.MicrosiemensPerCentimeter:
            return f"""{self.microsiemens_per_centimeter} """
        
        if unit == ElectricConductivityUnits.MillisiemensPerCentimeter:
            return f"""{self.millisiemens_per_centimeter} """
        
        return f'{self.__value}'


    def get_unit_abbreviation(self, unit_abbreviation: ElectricConductivityUnits = ElectricConductivityUnits.SiemensPerMeter) -> string:
        """
        Get ElectricConductivity unit abbreviation.
        Note! the default abbreviation for ElectricConductivity is SiemensPerMeter.
        To specify the unit abbreviation set the 'unit_abbreviation' parameter.
        """
        
        if unit_abbreviation == ElectricConductivityUnits.SiemensPerMeter:
            return """S/m"""
        
        if unit_abbreviation == ElectricConductivityUnits.SiemensPerInch:
            return """S/in"""
        
        if unit_abbreviation == ElectricConductivityUnits.SiemensPerFoot:
            return """S/ft"""
        
        if unit_abbreviation == ElectricConductivityUnits.SiemensPerCentimeter:
            return """S/cm"""
        
        if unit_abbreviation == ElectricConductivityUnits.MicrosiemensPerCentimeter:
            return """"""
        
        if unit_abbreviation == ElectricConductivityUnits.MillisiemensPerCentimeter:
            return """"""
        

    def __str__(self):
        return self.to_string()


    def __add__(self, other):
        if not isinstance(other, ElectricConductivity):
            raise TypeError("unsupported operand type(s) for +: 'ElectricConductivity' and '{}'".format(type(other).__name__))
        return ElectricConductivity(self.__value + other.__value)


    def __mul__(self, other):
        if not isinstance(other, ElectricConductivity):
            raise TypeError("unsupported operand type(s) for *: 'ElectricConductivity' and '{}'".format(type(other).__name__))
        return ElectricConductivity(self.__value * other.__value)


    def __sub__(self, other):
        if not isinstance(other, ElectricConductivity):
            raise TypeError("unsupported operand type(s) for -: 'ElectricConductivity' and '{}'".format(type(other).__name__))
        return ElectricConductivity(self.__value - other.__value)


    def __truediv__(self, other):
        if not isinstance(other, ElectricConductivity):
            raise TypeError("unsupported operand type(s) for /: 'ElectricConductivity' and '{}'".format(type(other).__name__))
        return ElectricConductivity(self.__value / other.__value)


    def __mod__(self, other):
        if not isinstance(other, ElectricConductivity):
            raise TypeError("unsupported operand type(s) for %: 'ElectricConductivity' and '{}'".format(type(other).__name__))
        return ElectricConductivity(self.__value % other.__value)


    def __pow__(self, other):
        if not isinstance(other, ElectricConductivity):
            raise TypeError("unsupported operand type(s) for **: 'ElectricConductivity' and '{}'".format(type(other).__name__))
        return ElectricConductivity(self.__value ** other.__value)


    def __eq__(self, other):
        if not isinstance(other, ElectricConductivity):
            raise TypeError("unsupported operand type(s) for ==: 'ElectricConductivity' and '{}'".format(type(other).__name__))
        return self.__value == other.__value


    def __lt__(self, other):
        if not isinstance(other, ElectricConductivity):
            raise TypeError("unsupported operand type(s) for <: 'ElectricConductivity' and '{}'".format(type(other).__name__))
        return self.__value < other.__value


    def __gt__(self, other):
        if not isinstance(other, ElectricConductivity):
            raise TypeError("unsupported operand type(s) for >: 'ElectricConductivity' and '{}'".format(type(other).__name__))
        return self.__value > other.__value


    def __le__(self, other):
        if not isinstance(other, ElectricConductivity):
            raise TypeError("unsupported operand type(s) for <=: 'ElectricConductivity' and '{}'".format(type(other).__name__))
        return self.__value <= other.__value


    def __ge__(self, other):
        if not isinstance(other, ElectricConductivity):
            raise TypeError("unsupported operand type(s) for >=: 'ElectricConductivity' and '{}'".format(type(other).__name__))
        return self.__value >= other.__value


from enum import Enum
import math
import string


class SpecificVolumeUnits(Enum):
        """
            SpecificVolumeUnits enumeration
        """
        
        CubicMeterPerKilogram = 'cubic_meter_per_kilogram'
        """
            
        """
        
        CubicFootPerPound = 'cubic_foot_per_pound'
        """
            
        """
        
        MillicubicMeterPerKilogram = 'millicubic_meter_per_kilogram'
        """
            
        """
        

class SpecificVolume:
    """
    In thermodynamics, the specific volume of a substance is the ratio of the substance's volume to its mass. It is the reciprocal of density and an intrinsic property of matter as well.

    Args:
        value (float): The value.
        from_unit (SpecificVolumeUnits): The SpecificVolume unit to create from, The default unit is CubicMeterPerKilogram
    """
    def __init__(self, value: float, from_unit: SpecificVolumeUnits = SpecificVolumeUnits.CubicMeterPerKilogram):
        if math.isnan(value):
            raise ValueError('Invalid unit: value is NaN')
        self.__value = self.__convert_to_base(value, from_unit)
        
        self.__cubic_meters_per_kilogram = None
        
        self.__cubic_feet_per_pound = None
        
        self.__millicubic_meters_per_kilogram = None
        

    def __convert_from_base(self, from_unit: SpecificVolumeUnits) -> float:
        value = self.__value
        
        if from_unit == SpecificVolumeUnits.CubicMeterPerKilogram:
            return (value)
        
        if from_unit == SpecificVolumeUnits.CubicFootPerPound:
            return (value * 16.01846353)
        
        if from_unit == SpecificVolumeUnits.MillicubicMeterPerKilogram:
            return ((value) / 0.001)
        
        return None


    def __convert_to_base(self, value: float, to_unit: SpecificVolumeUnits) -> float:
        
        if to_unit == SpecificVolumeUnits.CubicMeterPerKilogram:
            return (value)
        
        if to_unit == SpecificVolumeUnits.CubicFootPerPound:
            return (value / 16.01846353)
        
        if to_unit == SpecificVolumeUnits.MillicubicMeterPerKilogram:
            return ((value) * 0.001)
        
        return None


    @property
    def base_value(self) -> float:
        return self.__value

    
    @staticmethod
    def from_cubic_meters_per_kilogram(cubic_meters_per_kilogram: float):
        """
        Create a new instance of SpecificVolume from a value in cubic_meters_per_kilogram.

        

        :param meters: The SpecificVolume value in cubic_meters_per_kilogram.
        :type cubic_meters_per_kilogram: float
        :return: A new instance of SpecificVolume.
        :rtype: SpecificVolume
        """
        return SpecificVolume(cubic_meters_per_kilogram, SpecificVolumeUnits.CubicMeterPerKilogram)

    
    @staticmethod
    def from_cubic_feet_per_pound(cubic_feet_per_pound: float):
        """
        Create a new instance of SpecificVolume from a value in cubic_feet_per_pound.

        

        :param meters: The SpecificVolume value in cubic_feet_per_pound.
        :type cubic_feet_per_pound: float
        :return: A new instance of SpecificVolume.
        :rtype: SpecificVolume
        """
        return SpecificVolume(cubic_feet_per_pound, SpecificVolumeUnits.CubicFootPerPound)

    
    @staticmethod
    def from_millicubic_meters_per_kilogram(millicubic_meters_per_kilogram: float):
        """
        Create a new instance of SpecificVolume from a value in millicubic_meters_per_kilogram.

        

        :param meters: The SpecificVolume value in millicubic_meters_per_kilogram.
        :type millicubic_meters_per_kilogram: float
        :return: A new instance of SpecificVolume.
        :rtype: SpecificVolume
        """
        return SpecificVolume(millicubic_meters_per_kilogram, SpecificVolumeUnits.MillicubicMeterPerKilogram)

    
    @property
    def cubic_meters_per_kilogram(self) -> float:
        """
        
        """
        if self.__cubic_meters_per_kilogram != None:
            return self.__cubic_meters_per_kilogram
        self.__cubic_meters_per_kilogram = self.__convert_from_base(SpecificVolumeUnits.CubicMeterPerKilogram)
        return self.__cubic_meters_per_kilogram

    
    @property
    def cubic_feet_per_pound(self) -> float:
        """
        
        """
        if self.__cubic_feet_per_pound != None:
            return self.__cubic_feet_per_pound
        self.__cubic_feet_per_pound = self.__convert_from_base(SpecificVolumeUnits.CubicFootPerPound)
        return self.__cubic_feet_per_pound

    
    @property
    def millicubic_meters_per_kilogram(self) -> float:
        """
        
        """
        if self.__millicubic_meters_per_kilogram != None:
            return self.__millicubic_meters_per_kilogram
        self.__millicubic_meters_per_kilogram = self.__convert_from_base(SpecificVolumeUnits.MillicubicMeterPerKilogram)
        return self.__millicubic_meters_per_kilogram

    
    def to_string(self, unit: SpecificVolumeUnits = SpecificVolumeUnits.CubicMeterPerKilogram) -> string:
        """
        Format the SpecificVolume to string.
        Note! the default format for SpecificVolume is CubicMeterPerKilogram.
        To specify the unit format set the 'unit' parameter.
        """
        
        if unit == SpecificVolumeUnits.CubicMeterPerKilogram:
            return f"""{self.cubic_meters_per_kilogram} m³/kg"""
        
        if unit == SpecificVolumeUnits.CubicFootPerPound:
            return f"""{self.cubic_feet_per_pound} ft³/lb"""
        
        if unit == SpecificVolumeUnits.MillicubicMeterPerKilogram:
            return f"""{self.millicubic_meters_per_kilogram} """
        
        return f'{self.__value}'


    def get_unit_abbreviation(self, unit_abbreviation: SpecificVolumeUnits = SpecificVolumeUnits.CubicMeterPerKilogram) -> string:
        """
        Get SpecificVolume unit abbreviation.
        Note! the default abbreviation for SpecificVolume is CubicMeterPerKilogram.
        To specify the unit abbreviation set the 'unit_abbreviation' parameter.
        """
        
        if unit_abbreviation == SpecificVolumeUnits.CubicMeterPerKilogram:
            return """m³/kg"""
        
        if unit_abbreviation == SpecificVolumeUnits.CubicFootPerPound:
            return """ft³/lb"""
        
        if unit_abbreviation == SpecificVolumeUnits.MillicubicMeterPerKilogram:
            return """"""
        

    def __str__(self):
        return self.to_string()


    def __add__(self, other):
        if not isinstance(other, SpecificVolume):
            raise TypeError("unsupported operand type(s) for +: 'SpecificVolume' and '{}'".format(type(other).__name__))
        return SpecificVolume(self.__value + other.__value)


    def __mul__(self, other):
        if not isinstance(other, SpecificVolume):
            raise TypeError("unsupported operand type(s) for *: 'SpecificVolume' and '{}'".format(type(other).__name__))
        return SpecificVolume(self.__value * other.__value)


    def __sub__(self, other):
        if not isinstance(other, SpecificVolume):
            raise TypeError("unsupported operand type(s) for -: 'SpecificVolume' and '{}'".format(type(other).__name__))
        return SpecificVolume(self.__value - other.__value)


    def __truediv__(self, other):
        if not isinstance(other, SpecificVolume):
            raise TypeError("unsupported operand type(s) for /: 'SpecificVolume' and '{}'".format(type(other).__name__))
        return SpecificVolume(self.__value / other.__value)


    def __mod__(self, other):
        if not isinstance(other, SpecificVolume):
            raise TypeError("unsupported operand type(s) for %: 'SpecificVolume' and '{}'".format(type(other).__name__))
        return SpecificVolume(self.__value % other.__value)


    def __pow__(self, other):
        if not isinstance(other, SpecificVolume):
            raise TypeError("unsupported operand type(s) for **: 'SpecificVolume' and '{}'".format(type(other).__name__))
        return SpecificVolume(self.__value ** other.__value)


    def __eq__(self, other):
        if not isinstance(other, SpecificVolume):
            raise TypeError("unsupported operand type(s) for ==: 'SpecificVolume' and '{}'".format(type(other).__name__))
        return self.__value == other.__value


    def __lt__(self, other):
        if not isinstance(other, SpecificVolume):
            raise TypeError("unsupported operand type(s) for <: 'SpecificVolume' and '{}'".format(type(other).__name__))
        return self.__value < other.__value


    def __gt__(self, other):
        if not isinstance(other, SpecificVolume):
            raise TypeError("unsupported operand type(s) for >: 'SpecificVolume' and '{}'".format(type(other).__name__))
        return self.__value > other.__value


    def __le__(self, other):
        if not isinstance(other, SpecificVolume):
            raise TypeError("unsupported operand type(s) for <=: 'SpecificVolume' and '{}'".format(type(other).__name__))
        return self.__value <= other.__value


    def __ge__(self, other):
        if not isinstance(other, SpecificVolume):
            raise TypeError("unsupported operand type(s) for >=: 'SpecificVolume' and '{}'".format(type(other).__name__))
        return self.__value >= other.__value